searchData={"items":[{"type":"task","title":"mix task_validator","doc":"Task validation utilities for managing and validating structured task lists.\n\nTaskValidator provides tools for validating Markdown task lists against a structured \nformat specification, with enhanced support for Elixir/Phoenix projects.","ref":"Mix.Tasks.TaskValidator.html"},{"type":"task","title":"Available Commands - mix task_validator","doc":"","ref":"Mix.Tasks.TaskValidator.html#module-available-commands"},{"type":"task","title":"Validation - mix task_validator","doc":"mix validate_tasklist [--path FILE]\n    \nValidates a TaskList.md file against the format specification. \nSee `mix help validate_tasklist` for details.","ref":"Mix.Tasks.TaskValidator.html#module-validation"},{"type":"task","title":"Template Generation - mix task_validator","doc":"mix task_validator.create_template [OPTIONS]\n    \nCreates a new TaskList.md file with example tasks for different project categories.\nSee `mix help task_validator.create_template` for details.","ref":"Mix.Tasks.TaskValidator.html#module-template-generation"},{"type":"task","title":"Quick Start - mix task_validator","doc":"# Validate existing task list\n    mix validate_tasklist\n    \n    # Create a new task list template\n    mix task_validator.create_template\n    \n    # Create OTP-specific template with custom prefix\n    mix task_validator.create_template --category otp_genserver --prefix GEN\n    \n    # Validate one of the example templates\n    mix validate_tasklist --path docs/examples/phoenix_web_example.md","ref":"Mix.Tasks.TaskValidator.html#module-quick-start"},{"type":"task","title":"Task List Format - mix task_validator","doc":"Task lists must include:\n- Current Tasks table\n- Completed Tasks table  \n- Detailed task sections with required fields\n- Proper subtask organization (numbered or checkbox format)\n- Error handling documentation\n- Code quality metrics","ref":"Mix.Tasks.TaskValidator.html#module-task-list-format"},{"type":"task","title":"Categories - mix task_validator","doc":"TaskValidator supports these project categories:\n- **otp_genserver** - OTP/GenServer development\n- **phoenix_web** - Phoenix web development  \n- **business_logic** - Phoenix contexts and domain logic\n- **data_layer** - Ecto schemas and database design\n- **infrastructure** - Deployment and DevOps\n- **testing** - Test implementation strategies","ref":"Mix.Tasks.TaskValidator.html#module-categories"},{"type":"task","title":"Examples - mix task_validator","doc":"Complete working examples are available in `docs/examples/`:\n- `otp_genserver_example.md`\n- `phoenix_web_example.md`\n- `business_logic_example.md`\n- `data_layer_example.md`\n- `infrastructure_example.md`\n- `testing_example.md`","ref":"Mix.Tasks.TaskValidator.html#module-examples"},{"type":"task","title":"Learn More - mix task_validator","doc":"- Run `mix help validate_tasklist` for validation details\n- Run `mix help task_validator.create_template` for template options\n- See `README.md` for comprehensive documentation\n- Check `docs/examples/README.md` for example explanations","ref":"Mix.Tasks.TaskValidator.html#module-learn-more"},{"type":"module","title":"TaskValidator.Config","doc":"Configuration module for TaskValidator.\n\nProvides a centralized way to access and validate configuration options\nfor the TaskValidator library. All configuration is read from the\nApplication environment under the :task_validator key.","ref":"TaskValidator.Config.html"},{"type":"module","title":"Configuration Options - TaskValidator.Config","doc":"","ref":"TaskValidator.Config.html#module-configuration-options"},{"type":"module","title":"Validation Rules - TaskValidator.Config","doc":"* `:valid_statuses` - List of valid task statuses. \n    Default: `[\"Planned\", \"In Progress\", \"Review\", \"Completed\", \"Blocked\"]`\n    \n  * `:valid_priorities` - List of valid task priorities.\n    Default: `[\"Critical\", \"High\", \"Medium\", \"Low\"]`\n    \n  * `:id_regex` - Regular expression for validating task IDs.\n    Default: `~r/^[A-Z]{2,4}\\d{3,4}(-\\d+|[a-z])?$/`\n    \n  * `:rating_regex` - Regular expression for validating review ratings.\n    Default: `~r/^([1-5](\\.)?) *((partial))?$/`","ref":"TaskValidator.Config.html#module-validation-rules"},{"type":"module","title":"Code Quality KPIs - TaskValidator.Config","doc":"* `:max_functions_per_module` - Maximum allowed functions per module.\n    Default: `8`\n    \n  * `:max_lines_per_function` - Maximum allowed lines per function.\n    Default: `15`\n    \n  * `:max_call_depth` - Maximum allowed call depth.\n    Default: `3`","ref":"TaskValidator.Config.html#module-code-quality-kpis"},{"type":"module","title":"Elixir-Specific Code Quality KPIs - TaskValidator.Config","doc":"* `:max_pattern_match_depth` - Maximum allowed pattern matching depth.\n    Default: `4`\n    \n  * `:max_dialyzer_warnings` - Maximum allowed Dialyzer warnings.\n    Default: `0`\n    \n  * `:min_credo_score` - Minimum required Credo score (out of 10).\n    Default: `8.0`\n    \n  * `:max_genserver_state_complexity` - Maximum GenServer state fields.\n    Default: `5`\n    \n  * `:max_phoenix_context_boundaries` - Maximum contexts per feature.\n    Default: `3`\n    \n  * `:max_ecto_query_complexity` - Maximum Ecto query depth.\n    Default: `4`","ref":"TaskValidator.Config.html#module-elixir-specific-code-quality-kpis"},{"type":"module","title":"Task Categories - TaskValidator.Config","doc":"* `:category_ranges` - Map of category names to number ranges.\n    Default (Elixir/Phoenix-specific):\n    ```\n    %{\n      \"otp_genserver\" => {1, 99},\n      \"phoenix_web\" => {100, 199},\n      \"business_logic\" => {200, 299},\n      \"data_layer\" => {300, 399},\n      \"infrastructure\" => {400, 499},\n      \"testing\" => {500, 599}\n    }\n    ```","ref":"TaskValidator.Config.html#module-task-categories"},{"type":"module","title":"Example Configuration - TaskValidator.Config","doc":"# config/config.exs\n    config :task_validator,\n      valid_statuses: [\"Planning\", \"Active\", \"Done\", \"Paused\"],\n      max_functions_per_module: 7,\n      category_ranges: %{\n        \"otp_genserver\" => {1, 99},\n        \"phoenix_web\" => {100, 199},\n        \"business_logic\" => {200, 299},\n        \"data_layer\" => {300, 399},\n        \"infrastructure\" => {400, 499},\n        \"testing\" => {500, 599}\n      }","ref":"TaskValidator.Config.html#module-example-configuration"},{"type":"function","title":"TaskValidator.Config.get/1","doc":"Gets a configuration value with validation.\n\nReturns the configured value or the default if not set.\nValidates the configuration value matches expected type and constraints.","ref":"TaskValidator.Config.html#get/1"},{"type":"function","title":"Examples - TaskValidator.Config.get/1","doc":"iex> TaskValidator.Config.get(:valid_statuses)\n    [\"Planned\", \"In Progress\", \"Review\", \"Completed\", \"Blocked\"]\n    \n    iex> TaskValidator.Config.get(:max_functions_per_module)\n    5","ref":"TaskValidator.Config.html#get/1-examples"},{"type":"function","title":"TaskValidator.Config.get_all/0","doc":"Gets all configuration as a map.\n\nReturns a map with all configuration values, using defaults for any\nunconfigured options.","ref":"TaskValidator.Config.html#get_all/0"},{"type":"function","title":"TaskValidator.Config.validate_config_value/2","doc":"Validates a configuration value.\n\nReturns `:ok` if valid, or `{:error, reason}` if invalid.","ref":"TaskValidator.Config.html#validate_config_value/2"},{"type":"module","title":"TaskValidator.Core.Task","doc":"Core domain model representing a task in the task list.\n\nThis struct encapsulates all task-related data and provides a clear\ncontract for working with tasks throughout the validation system.","ref":"TaskValidator.Core.Task.html"},{"type":"function","title":"TaskValidator.Core.Task.add_subtask/2","doc":"Adds a subtask to the task.","ref":"TaskValidator.Core.Task.html#add_subtask/2"},{"type":"function","title":"TaskValidator.Core.Task.completed?/1","doc":"Checks if the task is completed.","ref":"TaskValidator.Core.Task.html#completed?/1"},{"type":"function","title":"TaskValidator.Core.Task.determine_category/1","doc":"Determines the category based on the task ID number.","ref":"TaskValidator.Core.Task.html#determine_category/1"},{"type":"function","title":"TaskValidator.Core.Task.extract_prefix/1","doc":"Extracts the prefix from a task ID (e.g., \"SSH\" from \"SSH0001\").","ref":"TaskValidator.Core.Task.html#extract_prefix/1"},{"type":"function","title":"TaskValidator.Core.Task.get_parent_id/1","doc":"Gets the parent task ID for a subtask.","ref":"TaskValidator.Core.Task.html#get_parent_id/1"},{"type":"function","title":"TaskValidator.Core.Task.in_progress?/1","doc":"Checks if the task is in progress.","ref":"TaskValidator.Core.Task.html#in_progress?/1"},{"type":"function","title":"TaskValidator.Core.Task.main_task?/1","doc":"Checks if the task is a main task.","ref":"TaskValidator.Core.Task.html#main_task?/1"},{"type":"function","title":"TaskValidator.Core.Task.new_main_task/6","doc":"Creates a new main task.","ref":"TaskValidator.Core.Task.html#new_main_task/6"},{"type":"function","title":"TaskValidator.Core.Task.new_subtask/6","doc":"Creates a new subtask.","ref":"TaskValidator.Core.Task.html#new_subtask/6"},{"type":"function","title":"TaskValidator.Core.Task.subtask?/1","doc":"Checks if the task is a subtask.","ref":"TaskValidator.Core.Task.html#subtask?/1"},{"type":"type","title":"TaskValidator.Core.Task.t/0","doc":"","ref":"TaskValidator.Core.Task.html#t:t/0"},{"type":"type","title":"TaskValidator.Core.Task.task_type/0","doc":"","ref":"TaskValidator.Core.Task.html#t:task_type/0"},{"type":"module","title":"TaskValidator.Core.TaskList","doc":"Represents a complete task list with all its tasks and metadata.\n\nThis aggregate encapsulates a collection of tasks along with\nvalidation metadata and reference definitions.","ref":"TaskValidator.Core.TaskList.html"},{"type":"function","title":"TaskValidator.Core.TaskList.find_task/2","doc":"Finds a task by ID.","ref":"TaskValidator.Core.TaskList.html#find_task/2"},{"type":"function","title":"TaskValidator.Core.TaskList.main_tasks/1","doc":"Gets all main tasks from the task list.","ref":"TaskValidator.Core.TaskList.html#main_tasks/1"},{"type":"function","title":"TaskValidator.Core.TaskList.new/3","doc":"Creates a new task list.","ref":"TaskValidator.Core.TaskList.html#new/3"},{"type":"function","title":"TaskValidator.Core.TaskList.reference_exists?/2","doc":"Checks if a reference exists in the task list.","ref":"TaskValidator.Core.TaskList.html#reference_exists?/2"},{"type":"function","title":"TaskValidator.Core.TaskList.stats/1","doc":"Gets statistics about the task list.","ref":"TaskValidator.Core.TaskList.html#stats/1"},{"type":"function","title":"TaskValidator.Core.TaskList.subtasks/1","doc":"Gets all subtasks from the task list.","ref":"TaskValidator.Core.TaskList.html#subtasks/1"},{"type":"type","title":"TaskValidator.Core.TaskList.t/0","doc":"","ref":"TaskValidator.Core.TaskList.html#t:t/0"},{"type":"function","title":"TaskValidator.Core.TaskList.task_count/1","doc":"Gets the total number of tasks.","ref":"TaskValidator.Core.TaskList.html#task_count/1"},{"type":"function","title":"TaskValidator.Core.TaskList.task_exists?/2","doc":"Checks if a task ID exists in the task list.","ref":"TaskValidator.Core.TaskList.html#task_exists?/2"},{"type":"function","title":"TaskValidator.Core.TaskList.task_ids/1","doc":"Gets all task IDs from the task list.","ref":"TaskValidator.Core.TaskList.html#task_ids/1"},{"type":"function","title":"TaskValidator.Core.TaskList.tasks_by_category/2","doc":"Gets tasks by category.","ref":"TaskValidator.Core.TaskList.html#tasks_by_category/2"},{"type":"function","title":"TaskValidator.Core.TaskList.tasks_by_status/2","doc":"Gets tasks by status.","ref":"TaskValidator.Core.TaskList.html#tasks_by_status/2"},{"type":"module","title":"TaskValidator.Core.ValidationError","doc":"Represents a validation error with structured information.\n\nThis struct provides a consistent format for validation errors\nthroughout the system, including error type, message, context,\nand location information.","ref":"TaskValidator.Core.ValidationError.html"},{"type":"function","title":"TaskValidator.Core.ValidationError.duplicate_task_id/2","doc":"Creates an error for duplicate task ID.","ref":"TaskValidator.Core.ValidationError.html#duplicate_task_id/2"},{"type":"type","title":"TaskValidator.Core.ValidationError.error_type/0","doc":"","ref":"TaskValidator.Core.ValidationError.html#t:error_type/0"},{"type":"function","title":"TaskValidator.Core.ValidationError.format/1","doc":"Formats the error for display.","ref":"TaskValidator.Core.ValidationError.html#format/1"},{"type":"function","title":"TaskValidator.Core.ValidationError.incomplete_error_handling/3","doc":"Creates an error for incomplete error handling documentation.","ref":"TaskValidator.Core.ValidationError.html#incomplete_error_handling/3"},{"type":"function","title":"TaskValidator.Core.ValidationError.invalid_dependency/3","doc":"Creates an error for invalid dependency reference.","ref":"TaskValidator.Core.ValidationError.html#invalid_dependency/3"},{"type":"function","title":"TaskValidator.Core.ValidationError.invalid_id_format/2","doc":"Creates an error for invalid task ID format.","ref":"TaskValidator.Core.ValidationError.html#invalid_id_format/2"},{"type":"function","title":"TaskValidator.Core.ValidationError.invalid_priority/3","doc":"Creates an error for invalid priority value.","ref":"TaskValidator.Core.ValidationError.html#invalid_priority/3"},{"type":"function","title":"TaskValidator.Core.ValidationError.invalid_status/3","doc":"Creates an error for invalid status value.","ref":"TaskValidator.Core.ValidationError.html#invalid_status/3"},{"type":"function","title":"TaskValidator.Core.ValidationError.invalid_subtask_prefix/4","doc":"Creates an error for invalid subtask prefix.","ref":"TaskValidator.Core.ValidationError.html#invalid_subtask_prefix/4"},{"type":"function","title":"TaskValidator.Core.ValidationError.kpi_violation/5","doc":"Creates an error for KPI violation.","ref":"TaskValidator.Core.ValidationError.html#kpi_violation/5"},{"type":"function","title":"TaskValidator.Core.ValidationError.missing_error_handling/2","doc":"Creates an error for missing error handling documentation.","ref":"TaskValidator.Core.ValidationError.html#missing_error_handling/2"},{"type":"function","title":"TaskValidator.Core.ValidationError.missing_reference/2","doc":"Creates an error for missing reference definition.","ref":"TaskValidator.Core.ValidationError.html#missing_reference/2"},{"type":"function","title":"TaskValidator.Core.ValidationError.missing_review_rating/2","doc":"Creates an error for missing review rating in completed subtask.","ref":"TaskValidator.Core.ValidationError.html#missing_review_rating/2"},{"type":"function","title":"TaskValidator.Core.ValidationError.missing_section/3","doc":"Creates an error for missing required section.","ref":"TaskValidator.Core.ValidationError.html#missing_section/3"},{"type":"function","title":"TaskValidator.Core.ValidationError.missing_subtasks/2","doc":"Creates an error for missing subtasks in \"In Progress\" task.","ref":"TaskValidator.Core.ValidationError.html#missing_subtasks/2"},{"type":"function","title":"TaskValidator.Core.ValidationError.new/3","doc":"Creates a new validation error.","ref":"TaskValidator.Core.ValidationError.html#new/3"},{"type":"type","title":"TaskValidator.Core.ValidationError.severity/0","doc":"","ref":"TaskValidator.Core.ValidationError.html#t:severity/0"},{"type":"type","title":"TaskValidator.Core.ValidationError.t/0","doc":"","ref":"TaskValidator.Core.ValidationError.html#t:t/0"},{"type":"module","title":"TaskValidator.Core.ValidationResult","doc":"Represents the result of a validation operation.\n\nThis struct aggregates validation errors and warnings, providing\na consistent interface for handling validation outcomes throughout\nthe system.","ref":"TaskValidator.Core.ValidationResult.html"},{"type":"function","title":"TaskValidator.Core.ValidationResult.add_error/2","doc":"Adds an error to the validation result.","ref":"TaskValidator.Core.ValidationResult.html#add_error/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.add_errors/2","doc":"Adds multiple errors to the validation result.","ref":"TaskValidator.Core.ValidationResult.html#add_errors/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.add_warning/2","doc":"Adds a warning to the validation result.","ref":"TaskValidator.Core.ValidationResult.html#add_warning/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.add_warnings/2","doc":"Adds multiple warnings to the validation result.","ref":"TaskValidator.Core.ValidationResult.html#add_warnings/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.combine/1","doc":"Combines multiple validation results into a single result.\n\nThe combined result is valid only if all input results are valid.\nAll errors and warnings are aggregated.","ref":"TaskValidator.Core.ValidationResult.html#combine/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.error_count/1","doc":"Gets the number of errors.","ref":"TaskValidator.Core.ValidationResult.html#error_count/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.errors_for_task/2","doc":"Gets errors for a specific task ID.","ref":"TaskValidator.Core.ValidationResult.html#errors_for_task/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.failure/2","doc":"Creates a failed validation result.","ref":"TaskValidator.Core.ValidationResult.html#failure/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.format/1","doc":"Formats the validation result for display.","ref":"TaskValidator.Core.ValidationResult.html#format/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.group_errors_by_type/1","doc":"Groups errors by type for analysis.","ref":"TaskValidator.Core.ValidationResult.html#group_errors_by_type/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.has_error_type?/2","doc":"Checks if a specific error type exists in the result.","ref":"TaskValidator.Core.ValidationResult.html#has_error_type?/2"},{"type":"function","title":"TaskValidator.Core.ValidationResult.has_issues?/1","doc":"Checks if the result has any issues (errors or warnings).","ref":"TaskValidator.Core.ValidationResult.html#has_issues?/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.issue_count/1","doc":"Gets the total number of issues (errors + warnings).","ref":"TaskValidator.Core.ValidationResult.html#issue_count/1"},{"type":"function","title":"TaskValidator.Core.ValidationResult.new/3","doc":"Creates a validation result with both errors and warnings.","ref":"TaskValidator.Core.ValidationResult.html#new/3"},{"type":"function","title":"TaskValidator.Core.ValidationResult.success/1","doc":"Creates a successful validation result.","ref":"TaskValidator.Core.ValidationResult.html#success/1"},{"type":"type","title":"TaskValidator.Core.ValidationResult.t/0","doc":"","ref":"TaskValidator.Core.ValidationResult.html#t:t/0"},{"type":"function","title":"TaskValidator.Core.ValidationResult.warning_count/1","doc":"Gets the number of warnings.","ref":"TaskValidator.Core.ValidationResult.html#warning_count/1"},{"type":"module","title":"TaskValidator.Parsers.MarkdownParser","doc":"Parses Markdown content for task validation.\n\nThis module handles the core parsing of Markdown files, extracting structured\ndata that can be validated by the TaskValidator system. It separates parsing\nconcerns from validation logic.","ref":"TaskValidator.Parsers.MarkdownParser.html"},{"type":"function","title":"TaskValidator.Parsers.MarkdownParser.extract_references/1","doc":"Extracts reference definitions from markdown content.\n\nReference definitions follow the format:\n## \\{\\{reference-name\\}\\} or ## #\\{\\{reference-name\\}\\}","ref":"TaskValidator.Parsers.MarkdownParser.html#extract_references/1"},{"type":"function","title":"TaskValidator.Parsers.MarkdownParser.extract_tasks/1","doc":"Extracts tasks from markdown content.\n\nLooks for tasks in both \"Current Tasks\" and \"Completed Tasks\" sections.","ref":"TaskValidator.Parsers.MarkdownParser.html#extract_tasks/1"},{"type":"function","title":"TaskValidator.Parsers.MarkdownParser.parse/1","doc":"Parses markdown content into a structured TaskList.\n\nReturns a TaskList struct containing all parsed tasks and metadata.","ref":"TaskValidator.Parsers.MarkdownParser.html#parse/1"},{"type":"function","title":"TaskValidator.Parsers.MarkdownParser.validate_references/2","doc":"Validates that all reference placeholders have corresponding definitions.","ref":"TaskValidator.Parsers.MarkdownParser.html#validate_references/2"},{"type":"module","title":"TaskValidator.Parsers.ReferenceResolver","doc":"Handles reference resolution and validation in TaskList documents.\n\nReferences allow for content reuse and reduce file size by 60-70%.\nThis module validates reference integrity without expanding them,\nas the TaskValidator only checks that references exist.","ref":"TaskValidator.Parsers.ReferenceResolver.html"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.expand_reference/2","doc":"Expands a single reference placeholder with its definition.\n\nThis function is provided for completeness but is not used by the\nTaskValidator, which only validates reference existence.","ref":"TaskValidator.Parsers.ReferenceResolver.html#expand_reference/2"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.extract_references/1","doc":"Extracts reference definitions from markdown lines.\n\nReference definitions follow the format:\n## \\{\\{reference-name\\}\\} or ## #\\{\\{reference-name\\}\\}\n\nReturns a map where keys are reference names and values are the content lines.","ref":"TaskValidator.Parsers.ReferenceResolver.html#extract_references/1"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.find_reference_usages/1","doc":"Finds all reference placeholders used in the content.\n\nReturns a list of {reference_name, line_number} tuples for all\n\\{\\{reference-name\\}\\} placeholders found in the document.","ref":"TaskValidator.Parsers.ReferenceResolver.html#find_reference_usages/1"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.reference_stats/1","doc":"Gets statistics about reference usage in a TaskList.","ref":"TaskValidator.Parsers.ReferenceResolver.html#reference_stats/1"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.validate_reference_integrity/2","doc":"Validates reference integrity for a TaskList.\n\nThis is the main validation function that ensures all used references\nhave corresponding definitions.","ref":"TaskValidator.Parsers.ReferenceResolver.html#validate_reference_integrity/2"},{"type":"function","title":"TaskValidator.Parsers.ReferenceResolver.validate_references/1","doc":"Validates that all reference placeholders have corresponding definitions.\n\nThis function does NOT expand references - it only validates that every\n\\{\\{reference-name\\}\\} placeholder has a matching ## #\\{\\{reference-name\\}\\} definition.","ref":"TaskValidator.Parsers.ReferenceResolver.html#validate_references/1"},{"type":"module","title":"TaskValidator.Parsers.TaskExtractor","doc":"Extracts tasks from markdown table and detailed sections.\n\nThis module specializes in parsing different task formats found in TaskList\ndocuments, including table rows and detailed task sections with subtasks.","ref":"TaskValidator.Parsers.TaskExtractor.html"},{"type":"function","title":"TaskValidator.Parsers.TaskExtractor.extract_detailed_tasks/1","doc":"Extracts detailed task sections from markdown content.\n\nLooks for sections that start with \"","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_detailed_tasks/1"},{"type":"function","title":"TASKID:\" and extracts all - TaskValidator.Parsers.TaskExtractor.extract_detailed_tasks/1","doc":"content and subtasks for each task.","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_detailed_tasks/1-taskid-and-extracts-all"},{"type":"function","title":"TaskValidator.Parsers.TaskExtractor.extract_from_table/3","doc":"Extracts tasks from a markdown table section.","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_from_table/3"},{"type":"function","title":"Parameters - TaskValidator.Parsers.TaskExtractor.extract_from_table/3","doc":"- `lines`: List of markdown lines\n- `section_header`: The header to look for (e.g., \"","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_from_table/3-parameters"},{"type":"function","title":"Current Tasks\") - TaskValidator.Parsers.TaskExtractor.extract_from_table/3","doc":"- `default_status`: Default status to assign to tasks from this section","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_from_table/3-current-tasks"},{"type":"function","title":"Returns - TaskValidator.Parsers.TaskExtractor.extract_from_table/3","doc":"`{:ok, list(Task.t())}` with extracted tasks or `{:error, reason}`","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_from_table/3-returns"},{"type":"function","title":"TaskValidator.Parsers.TaskExtractor.extract_subtasks/1","doc":"Extracts subtasks from a task content section.\n\nSupports both numbered subtasks (#### 1. Description (TASK001-1))\nand checkbox subtasks (- [x] Description [TASK001a]).","ref":"TaskValidator.Parsers.TaskExtractor.html#extract_subtasks/1"},{"type":"function","title":"TaskValidator.Parsers.TaskExtractor.merge_table_with_details/2","doc":"Merges table tasks with their detailed task information.\n\nTable tasks provide basic metadata while detailed tasks provide\nfull content, subtasks, and additional fields.","ref":"TaskValidator.Parsers.TaskExtractor.html#merge_table_with_details/2"},{"type":"module","title":"TaskValidator.ValidationPipeline","doc":"Simple validation pipeline for running validators in priority order.\n\nProvides a clean, straightforward way to validate tasks using a configurable\nlist of validators without the complexity of a full rule engine.","ref":"TaskValidator.ValidationPipeline.html"},{"type":"module","title":"Usage - TaskValidator.ValidationPipeline","doc":"# Use default validators\n    result = ValidationPipeline.run(task, context)\n    \n    # Use custom validator list\n    validators = [\n      {TaskValidator.Validators.IdValidator, %{}},\n      {TaskValidator.Validators.StatusValidator, %{}}\n    ]\n    result = ValidationPipeline.run(task, context, validators)\n    \n    # Validate multiple tasks\n    results = ValidationPipeline.run_many(tasks, context, validators)","ref":"TaskValidator.ValidationPipeline.html#module-usage"},{"type":"function","title":"TaskValidator.ValidationPipeline.build_validators/1","doc":"Creates a custom validator set from a keyword list.","ref":"TaskValidator.ValidationPipeline.html#build_validators/1"},{"type":"function","title":"Example - TaskValidator.ValidationPipeline.build_validators/1","doc":"validators = ValidationPipeline.build_validators([\n      id: [strict_format: true],\n      status: [],\n      custom: [MyCustomValidator, [option: value]]\n    ])","ref":"TaskValidator.ValidationPipeline.html#build_validators/1-example"},{"type":"function","title":"TaskValidator.ValidationPipeline.default_validators/0","doc":"Returns the default set of validators in priority order.","ref":"TaskValidator.ValidationPipeline.html#default_validators/0"},{"type":"function","title":"TaskValidator.ValidationPipeline.minimal_validators/0","doc":"Returns a minimal validator set for basic validation.","ref":"TaskValidator.ValidationPipeline.html#minimal_validators/0"},{"type":"function","title":"TaskValidator.ValidationPipeline.run/3","doc":"Runs validation pipeline on a single task.","ref":"TaskValidator.ValidationPipeline.html#run/3"},{"type":"function","title":"Parameters - TaskValidator.ValidationPipeline.run/3","doc":"- `task` - The task to validate\n- `context` - Validation context (config, references, etc.)\n- `validators` - List of {validator_module, options} tuples (optional)","ref":"TaskValidator.ValidationPipeline.html#run/3-parameters"},{"type":"function","title":"Returns - TaskValidator.ValidationPipeline.run/3","doc":"Combined ValidationResult from all validators","ref":"TaskValidator.ValidationPipeline.html#run/3-returns"},{"type":"function","title":"TaskValidator.ValidationPipeline.run_many/3","doc":"Runs validation pipeline on multiple tasks.","ref":"TaskValidator.ValidationPipeline.html#run_many/3"},{"type":"function","title":"Parameters - TaskValidator.ValidationPipeline.run_many/3","doc":"- `tasks` - List of tasks to validate\n- `context` - Validation context\n- `validators` - List of validator specs (optional)","ref":"TaskValidator.ValidationPipeline.html#run_many/3-parameters"},{"type":"function","title":"Returns - TaskValidator.ValidationPipeline.run_many/3","doc":"Combined ValidationResult from all task validations","ref":"TaskValidator.ValidationPipeline.html#run_many/3-returns"},{"type":"function","title":"TaskValidator.ValidationPipeline.strict_validators/1","doc":"Returns a strict validator set with enhanced checking.","ref":"TaskValidator.ValidationPipeline.html#strict_validators/1"},{"type":"type","title":"TaskValidator.ValidationPipeline.validation_context/0","doc":"","ref":"TaskValidator.ValidationPipeline.html#t:validation_context/0"},{"type":"type","title":"TaskValidator.ValidationPipeline.validator_spec/0","doc":"","ref":"TaskValidator.ValidationPipeline.html#t:validator_spec/0"},{"type":"module","title":"TaskValidator.Validators.CategoryValidator","doc":"Validates task category assignment based on task ID numbers.\n\nThis validator ensures that tasks are properly categorized based on their\ntask ID numbers. It supports both standard categories and custom\ncategory configurations. Category-specific section validation is handled\nby the SectionValidator.","ref":"TaskValidator.Validators.CategoryValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.CategoryValidator","doc":"1. **Category Assignment**: Tasks are categorized based on ID number ranges (Elixir/Phoenix-specific)\n   - OTP/GenServer (001-099): Supervision trees, GenServers, Agents\n   - Phoenix Web (100-199): Controllers, views, LiveView, channels\n   - Business Logic (200-299): Contexts, schemas, core logic\n   - Data Layer (300-399): Ecto schemas, migrations, repos\n   - Infrastructure (400-499): Releases, deployment, monitoring\n   - Testing (500-599): Unit, integration, property-based tests\n\n2. **ID Format Support**: Handles multiple ID formats\n   - Standard format: SSH001, VAL0004 (extracts number for categorization)\n   - Custom format: PROJ-001, CORE-123 (extracts number after dash)\n\n3. **Configurable Categories**: Category ranges configurable\n   - Default ranges can be overridden in configuration\n   - Custom categories can be defined with specific ranges","ref":"TaskValidator.Validators.CategoryValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.CategoryValidator","doc":"- `:invalid_category_range` - Task ID number doesn't fit any category\n- `:invalid_id_for_categorization` - Cannot extract number for categorization","ref":"TaskValidator.Validators.CategoryValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.CategoryValidator","doc":"# Task ID OTP001 -> Category :otp_genserver (range 1-99)\n    # Task ID PHX101 -> Category :phoenix_web (range 100-199)\n    # Task ID CTX201 -> Category :business_logic (range 200-299)\n    # Task ID DB301 -> Category :data_layer (range 300-399)\n    # Task ID INF401 -> Category :infrastructure (range 400-499)\n    # Task ID TST501 -> Category :testing (range 500-599)\n\n    # Also supports custom formats:\n    # Task ID PROJ-001 -> Category :otp_genserver\n    # Task ID CORE-123 -> Category :phoenix_web","ref":"TaskValidator.Validators.CategoryValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.CategoryValidator.priority/0","doc":"Returns low priority (35) since category validation is useful for\norganization but not critical for basic task functionality.","ref":"TaskValidator.Validators.CategoryValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.CategoryValidator.validate/2","doc":"Validates task category assignment and category-specific requirements.","ref":"TaskValidator.Validators.CategoryValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.CategoryValidator.validate/2","doc":"- `:config` - TaskValidator configuration (optional, uses defaults)","ref":"TaskValidator.Validators.CategoryValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.CategoryValidator.validate/2","doc":"- Success if all category validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.CategoryValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.DependencyValidator","doc":"Validates task dependencies and dependency relationships.\n\nThis validator ensures that task dependencies are properly formatted,\nreference valid tasks, and don't create circular dependency chains.\nIt supports both explicit dependencies and reference-based dependency\nspecifications.","ref":"TaskValidator.Validators.DependencyValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.DependencyValidator","doc":"1. **Dependency Format**:\n   - **Dependencies**: None (for tasks with no dependencies)\n   - **Dependencies**: TASK001, TASK002 (comma-separated list)\n   - Can use `{{def-no-dependencies}}` or `{{no-dependencies}}` references\n\n2. **Dependency Existence**:\n   - All referenced task IDs must exist in the task list\n   - Dependencies can reference both main tasks and subtasks\n   - Case-sensitive task ID matching\n\n3. **Circular Dependency Detection**:\n   - Tasks cannot depend on themselves (direct circular dependency)\n   - Tasks cannot create dependency loops (indirect circular dependency)\n   - Validates entire dependency chain for cycles\n\n4. **Reference Support**:\n   - Supports standard dependency references\n   - Validates reference existence in reference map\n   - Allows flexible dependency specification","ref":"TaskValidator.Validators.DependencyValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.DependencyValidator","doc":"- `:missing_dependencies_section` - No Dependencies section found\n- `:invalid_dependency_reference` - Referenced task does not exist\n- `:circular_dependency` - Dependency creates a circular reference\n- `:invalid_dependency_format` - Dependencies not properly formatted\n- `:missing_dependency_reference` - Referenced dependency definition not found","ref":"TaskValidator.Validators.DependencyValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.DependencyValidator","doc":"# Valid no dependencies\n    **Dependencies**: None\n    \n    # Valid with reference\n    {{def-no-dependencies}}\n    \n    # Valid explicit dependencies\n    **Dependencies**: SSH001, VAL0004-1, CORE-123\n    \n    # Valid alternative reference\n    {{no-dependencies}}\n\n    # Invalid - non-existent task\n    **Dependencies**: SSH999, INVALID001\n    \n    # Invalid - circular dependency\n    Task A depends on Task B, Task B depends on Task A","ref":"TaskValidator.Validators.DependencyValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.DependencyValidator.priority/0","doc":"Returns medium priority (40) since dependency validation depends on\ntask structure but is less critical than ID or status validation.","ref":"TaskValidator.Validators.DependencyValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.DependencyValidator.validate/2","doc":"Validates task dependencies according to format and existence rules.","ref":"TaskValidator.Validators.DependencyValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.DependencyValidator.validate/2","doc":"- `:all_tasks` - List of all tasks for dependency validation\n- `:references` - Available references for validation (optional)","ref":"TaskValidator.Validators.DependencyValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.DependencyValidator.validate/2","doc":"- Success if all dependency validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.DependencyValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.ErrorHandlingValidator","doc":"Validates error handling sections and requirements for tasks.\n\nThis validator ensures that tasks have appropriate error handling documentation\naccording to their type (main task vs subtask) and implements the comprehensive\nerror handling guidelines defined for the project.","ref":"TaskValidator.Validators.ErrorHandlingValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.ErrorHandlingValidator","doc":"1. **Main Tasks**: Must have comprehensive error handling sections\n   - **Error Handling** with Core Principles, Implementation, Examples, GenServer Specifics\n   - Can use `{{error-handling}}` reference instead of explicit sections\n   - All required subsections must be present if not using references\n\n2. **Subtasks**: Have simplified error handling requirements\n   - **Error Handling** with Task-Specific Approach and Error Reporting\n   - Can use `{{error-handling-subtask}}` or `{{subtask-error-handling}}` references\n   - More focused on task-specific error patterns\n\n3. **Reference Support**: Validates proper reference usage\n   - Checks for valid error handling references in content\n   - Allows references to substitute for explicit sections\n   - Maintains compatibility with reference system\n\n4. **Completed Tasks**: Additional error handling implementation validation\n   - Must have **Error Handling Implementation** section\n   - Documents actual error handling patterns used","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.ErrorHandlingValidator","doc":"- `:missing_error_handling` - No error handling section or reference found\n- `:incomplete_error_handling` - Missing required error handling subsections\n- `:invalid_error_handling_format` - Error handling content doesn't match expected format\n- `:missing_error_implementation` - Completed task missing implementation details","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.ErrorHandlingValidator","doc":"# Valid main task error handling (explicit)\n    **Error Handling**\n    **Core Principles**\n    - Pass raw errors\n    - Use {:ok, result} | {:error, reason}\n    - Let it crash\n    **Error Implementation**\n    - No wrapping\n    - Minimal rescue\n    - function/1 & /! versions\n    **Error Examples**\n    - Raw error passthrough\n    - Simple rescue case\n    - Supervisor handling\n    **GenServer Specifics**\n    - Handle_call/3 error pattern\n    - Terminate/2 proper usage\n    - Process linking considerations\n\n    # Valid using reference\n    {{error-handling}}\n\n    # Valid subtask error handling\n    **Error Handling**\n    **Task-Specific Approach**\n    - Error pattern for this task\n    **Error Reporting**\n    - Monitoring approach","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.ErrorHandlingValidator.priority/0","doc":"Returns medium priority (55) since error handling validation is important\nbut should run after basic structure validation.","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.ErrorHandlingValidator.validate/2","doc":"Validates error handling sections according to task type and status.","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.ErrorHandlingValidator.validate/2","doc":"- `:references` - Available references for validation (optional)","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.ErrorHandlingValidator.validate/2","doc":"- Success if error handling requirements are met\n- Failure with specific error details for missing or invalid sections","ref":"TaskValidator.Validators.ErrorHandlingValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.IdValidator","doc":"Validates task IDs according to configured format rules.\n\nThis validator ensures that task IDs conform to the expected format,\nhandles both main task and subtask ID patterns, and validates that\nsubtask IDs properly reference their parent tasks.","ref":"TaskValidator.Validators.IdValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.IdValidator","doc":"1. **Main Task IDs**: Must match the configured ID regex pattern\n   - Default pattern: `[A-Z]{2,4}\\d{3,4}` (e.g., SSH001, VAL0004)\n   - Custom patterns: Can include dashes (e.g., PROJ-001, CORE-123)\n\n2. **Subtask IDs**: Must follow parent-child relationship patterns\n   - Numbered subtasks: `PARENT-\\d+` (e.g., SSH001-1, VAL0004-2)\n   - Letter subtasks: `PARENT[a-z]` (e.g., SSH001a, VAL0004b)\n\n3. **Prefix Consistency**: All tasks in a task list should use consistent prefixes\n   - Mixed prefixes are allowed but flagged as warnings\n   - Helps identify potential organizational issues\n\n4. **Duplicate Detection**: Ensures no duplicate task IDs exist","ref":"TaskValidator.Validators.IdValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.IdValidator","doc":"- `:invalid_id_format` - ID doesn't match expected pattern\n- `:duplicate_task_id` - Multiple tasks with same ID\n- `:invalid_subtask_id` - Subtask ID doesn't reference valid parent\n- `:mixed_prefixes` - Multiple prefixes detected (warning only)","ref":"TaskValidator.Validators.IdValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.IdValidator","doc":"# Valid main task IDs\n    \"SSH001\", \"VAL0004\", \"PROJ-001\", \"CORE-123\"\n    \n    # Valid subtask IDs\n    \"SSH001-1\", \"VAL0004-2\", \"SSH001a\", \"VAL0004b\"\n    \n    # Invalid IDs\n    \"ssh001\"      # lowercase\n    \"S001\"        # too few letters\n    \"SUPER001\"    # too many letters\n    \"SSH\"         # missing numbers","ref":"TaskValidator.Validators.IdValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.IdValidator.priority/0","doc":"Returns high priority (90) since ID validation is fundamental.\n\nID validation should run early as many other validators depend on\nvalid task IDs for their logic.","ref":"TaskValidator.Validators.IdValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.IdValidator.validate/2","doc":"Validates task ID format, uniqueness, and subtask relationships.","ref":"TaskValidator.Validators.IdValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.IdValidator.validate/2","doc":"- `:all_tasks` - List of all tasks for duplicate and parent validation\n- `:config` - TaskValidator configuration (optional, uses defaults)","ref":"TaskValidator.Validators.IdValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.IdValidator.validate/2","doc":"- Success if all ID validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.IdValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.KpiValidator","doc":"Validates code quality KPIs (Key Performance Indicators) for tasks.\n\nThis validator ensures that tasks have appropriate code quality metrics\ndefined and that these metrics meet the configured standards. It supports\nboth explicit KPI definitions and reference-based KPI specifications.","ref":"TaskValidator.Validators.KpiValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.KpiValidator","doc":"1. **Required KPIs**: Tasks must have code quality KPIs section or reference\n   - **Code Quality KPIs** section with specific metrics\n   - Can use `{{standard-kpis}}` reference instead\n\n2. **Standard KPI Metrics**:\n   - Functions per module: Maximum number of functions in a module\n   - Lines per function: Maximum lines of code per function\n   - Call depth: Maximum nested function call depth\n   - Additional metrics can be configured\n\n3. **KPI Value Validation**:\n   - All KPI values must be numeric and within configured limits\n   - Values should reflect realistic coding standards\n   - Metrics must be measurable and enforceable\n\n4. **Reference Support**:\n   - Supports standard KPI references like `{{standard-kpis}}`\n   - Validates reference existence in reference map\n   - Allows flexible KPI specification via references","ref":"TaskValidator.Validators.KpiValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.KpiValidator","doc":"- `:missing_kpi_section` - No Code Quality KPIs section or reference found\n- `:missing_kpi_metrics` - Required KPI metrics not specified\n- `:invalid_kpi_value` - KPI value exceeds configured limits\n- `:invalid_kpi_format` - KPI not properly formatted\n- `:missing_kpi_reference` - Referenced KPI definition not found","ref":"TaskValidator.Validators.KpiValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.KpiValidator","doc":"# Valid explicit KPIs\n    **Code Quality KPIs**\n    - Functions per module: 8\n    - Lines per function: 15\n    - Call depth: 3\n\n    # Valid with reference\n    {{standard-kpis}}\n\n    # Valid custom KPIs\n    **Code Quality KPIs**\n    - Functions per module: 10\n    - Lines per function: 20\n    - Call depth: 4\n    - Cyclomatic complexity: 8\n\n    # Invalid - exceeds limits\n    **Code Quality KPIs**  \n    - Functions per module: 25  # Too high\n    - Lines per function: 100   # Too high\n    - Call depth: 10           # Too deep","ref":"TaskValidator.Validators.KpiValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.KpiValidator.priority/0","doc":"Returns low priority (30) since KPI validation is important for\ncode quality but not critical for basic task structure.","ref":"TaskValidator.Validators.KpiValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.KpiValidator.validate/2","doc":"Validates code quality KPIs according to configured standards.","ref":"TaskValidator.Validators.KpiValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.KpiValidator.validate/2","doc":"- `:config` - TaskValidator configuration (optional, uses defaults)\n- `:references` - Available references for validation (optional)","ref":"TaskValidator.Validators.KpiValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.KpiValidator.validate/2","doc":"- Success if all KPI validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.KpiValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.SectionValidator","doc":"Validates that tasks contain all required sections according to their type and status.\n\nThis validator ensures that tasks have the appropriate content sections based on:\n- Task type (main task vs subtask)\n- Task status (Planned, In Progress, Completed, etc.)\n- Task category (core, features, documentation, testing)","ref":"TaskValidator.Validators.SectionValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.SectionValidator","doc":"1. **Main Task Required Sections**:\n   - **Description**: Task description and purpose\n   - **Requirements**: What needs to be accomplished\n   - **Dependencies**: Other tasks this depends on\n   - **Error Handling**: Comprehensive error handling documentation\n   - **Status**: Current status\n   - **Priority**: Task priority level\n\n2. **Completed Task Additional Sections**:\n   - **Implementation Notes**: How the task was completed\n   - **Complexity Assessment**: Assessment of implementation complexity\n   - **Maintenance Impact**: How this affects ongoing maintenance\n   - **Error Handling Implementation**: Actual error handling implemented\n\n3. **Subtask Sections**:\n   - **Description**: What the subtask accomplishes\n   - **Status**: Current status\n   - **Error Handling**: Simplified task-specific error handling\n\n4. **Status-Specific Requirements**:\n   - \"In Progress\" tasks may have additional status tracking sections\n   - \"Blocked\" tasks should document blocking issues\n   - \"Review\" tasks should have review criteria","ref":"TaskValidator.Validators.SectionValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.SectionValidator","doc":"- `:missing_required_section` - Required section not found in task content\n- `:invalid_section_format` - Section exists but format is incorrect\n- `:missing_error_handling` - Error handling section missing or incomplete\n- `:incomplete_completed_task` - Completed task missing required sections","ref":"TaskValidator.Validators.SectionValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.SectionValidator","doc":"# Required sections for main task\n    **Description**\n    **Requirements** \n    **Dependencies**\n    **Error Handling**\n    **Status**\n    **Priority**\n    \n    # Additional sections for completed tasks\n    **Implementation Notes**\n    **Complexity Assessment** \n    **Maintenance Impact**\n    **Error Handling Implementation**","ref":"TaskValidator.Validators.SectionValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.SectionValidator.priority/0","doc":"Returns medium priority (50) as section validation depends on\ntask structure being valid first.","ref":"TaskValidator.Validators.SectionValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.SectionValidator.validate/2","doc":"Validates that tasks contain all required sections for their type and status.","ref":"TaskValidator.Validators.SectionValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.SectionValidator.validate/2","doc":"- `:references` - Available references that might contain required sections","ref":"TaskValidator.Validators.SectionValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.SectionValidator.validate/2","doc":"- Success if all required sections are present\n- Failure with specific details about missing sections","ref":"TaskValidator.Validators.SectionValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.StatusValidator","doc":"Validates task status and priority values according to configured rules.\n\nThis validator ensures that tasks have valid status and priority values,\nand enforces business rules about status transitions and requirements.","ref":"TaskValidator.Validators.StatusValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.StatusValidator","doc":"1. **Valid Status Values**: Must be one of the configured valid statuses\n   - Default: `[\"Planned\", \"In Progress\", \"Review\", \"Completed\", \"Blocked\"]`\n   - Case-sensitive validation\n\n2. **Valid Priority Values**: Must be one of the configured valid priorities  \n   - Default: `[\"Critical\", \"High\", \"Medium\", \"Low\"]`\n   - Case-sensitive validation\n\n3. **Status-Dependent Requirements**:\n   - \"In Progress\" main tasks must have at least one subtask\n   - \"Completed\" tasks must have additional required sections\n   - \"Blocked\" tasks should have blocking reason documentation\n\n4. **Review Ratings**: Completed subtasks must have valid review ratings\n   - Format: `N.N` where N is 1-5, optional `(partial)` suffix\n   - Examples: \"4.5\", \"3.0\", \"5.0 (partial)\"","ref":"TaskValidator.Validators.StatusValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.StatusValidator","doc":"- `:invalid_status` - Status not in configured valid values\n- `:invalid_priority` - Priority not in configured valid values  \n- `:invalid_review_rating` - Review rating format incorrect\n- `:missing_subtasks_for_in_progress` - In Progress task without subtasks\n- `:missing_review_rating` - Completed subtask without rating","ref":"TaskValidator.Validators.StatusValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.StatusValidator","doc":"# Valid statuses (default)\n    \"Planned\", \"In Progress\", \"Review\", \"Completed\", \"Blocked\"\n    \n    # Valid priorities (default)  \n    \"Critical\", \"High\", \"Medium\", \"Low\"\n    \n    # Valid review ratings\n    \"4.5\", \"3.0\", \"5.0 (partial)\", \"1.0\"","ref":"TaskValidator.Validators.StatusValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.StatusValidator.priority/0","doc":"Returns medium priority (60) since status validation is important but\nnot as fundamental as ID validation.","ref":"TaskValidator.Validators.StatusValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.StatusValidator.validate/2","doc":"Validates task status, priority, and related business rules.","ref":"TaskValidator.Validators.StatusValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.StatusValidator.validate/2","doc":"- `:config` - TaskValidator configuration (optional, uses defaults)","ref":"TaskValidator.Validators.StatusValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.StatusValidator.validate/2","doc":"- Success if all status/priority validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.StatusValidator.html#validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.SubtaskValidator","doc":"Validates subtask structure, consistency, and format requirements.\n\nThis validator handles validation of subtasks including their format,\nstatus consistency, and relationships with parent tasks. It supports\nboth traditional numbered subtasks and checkbox-style subtasks.","ref":"TaskValidator.Validators.SubtaskValidator.html"},{"type":"module","title":"Validation Rules - TaskValidator.Validators.SubtaskValidator","doc":"1. **Subtask Format Validation**:\n   - Traditional numbered format: `#### N. Description (TASKID-N)`\n   - Checkbox format: `- [ ] Description [TASKID]` or `- [x] Description [TASKID]`\n   - Letter subtasks: `TASKID[a-z]` format support\n\n2. **Status Consistency**:\n   - Checkbox checked state must match status field (for traditional format)\n   - Completed subtasks must have review ratings (traditional format only)\n   - Valid status values according to configuration\n\n3. **Required Sections** (Traditional Format):\n   - **Status** - Current subtask status\n   - Error handling (explicit or via reference)\n   - Review rating for completed subtasks\n\n4. **Prefix Consistency**:\n   - Subtask IDs must use same prefix as parent task\n   - Validates parent-child relationships are maintained","ref":"TaskValidator.Validators.SubtaskValidator.html#module-validation-rules"},{"type":"module","title":"Error Types - TaskValidator.Validators.SubtaskValidator","doc":"- `:missing_subtask_status` - Subtask missing status field\n- `:invalid_subtask_status` - Status not in valid values\n- `:missing_review_rating` - Completed subtask without rating\n- `:invalid_review_rating` - Rating format incorrect\n- `:inconsistent_subtask_prefix` - Prefix doesn't match parent\n- `:missing_subtask_sections` - Required sections not present","ref":"TaskValidator.Validators.SubtaskValidator.html#module-error-types"},{"type":"module","title":"Examples - TaskValidator.Validators.SubtaskValidator","doc":"# Valid traditional numbered subtask\n    #### 1. Implement basic validation (SSH001-1)\n    \n    **Status**: In Progress\n    \n    {{error-handling-subtask}}\n\n    # Valid checkbox subtask\n    - [x] Add input validation [SSH001a]\n    - [ ] Implement error handling [SSH001b]\n\n    # Valid completed subtask (traditional)\n    #### 2. Add comprehensive tests (SSH001-2)\n    \n    **Status**: Completed\n    **Review Rating**: 4.5\n    \n    {{error-handling-subtask}}","ref":"TaskValidator.Validators.SubtaskValidator.html#module-examples"},{"type":"function","title":"TaskValidator.Validators.SubtaskValidator.priority/0","doc":"Returns medium priority (45) since subtask validation depends on\nbasic structure but should run before complex business rules.","ref":"TaskValidator.Validators.SubtaskValidator.html#priority/0"},{"type":"function","title":"TaskValidator.Validators.SubtaskValidator.validate/2","doc":"Validates subtask structure, status, and required sections.","ref":"TaskValidator.Validators.SubtaskValidator.html#validate/2"},{"type":"function","title":"Context Requirements - TaskValidator.Validators.SubtaskValidator.validate/2","doc":"- `:config` - TaskValidator configuration (optional, uses defaults)\n- `:references` - Available references for validation (optional)","ref":"TaskValidator.Validators.SubtaskValidator.html#validate/2-context-requirements"},{"type":"function","title":"Returns - TaskValidator.Validators.SubtaskValidator.validate/2","doc":"- Success if all subtask validations pass\n- Failure with specific error details for each validation issue","ref":"TaskValidator.Validators.SubtaskValidator.html#validate/2-returns"},{"type":"behaviour","title":"TaskValidator.Validators.ValidatorBehaviour","doc":"Defines the behaviour for TaskValidator validators.\n\nThis behaviour ensures all validators follow a consistent interface for\nvalidating tasks. Each validator should implement the `validate/2` function\nthat takes a task and context, returning a validation result.","ref":"TaskValidator.Validators.ValidatorBehaviour.html"},{"type":"behaviour","title":"Example Implementation - TaskValidator.Validators.ValidatorBehaviour","doc":"defmodule TaskValidator.Validators.ExampleValidator do\n      @behaviour TaskValidator.Validators.ValidatorBehaviour\n      \n      alias TaskValidator.Core.{ValidationResult, ValidationError}\n      \n      def validate(task, context) do\n        if valid?(task, context) do\n          ValidationResult.success()\n        else\n          error = %ValidationError{\n            type: :example_validation_error,\n            message: \"Task failed example validation\",\n            task_id: task.id,\n            line_number: task.line_number\n          }\n          ValidationResult.failure(error)\n        end\n      end\n      \n      defp valid?(task, context), do: # validation logic\n    end","ref":"TaskValidator.Validators.ValidatorBehaviour.html#module-example-implementation"},{"type":"behaviour","title":"Context - TaskValidator.Validators.ValidatorBehaviour","doc":"The context parameter provides additional information that validators might need:\n- `:config` - TaskValidator configuration\n- `:all_tasks` - List of all tasks for cross-task validation\n- `:references` - Available references in the document\n- `:task_list` - The complete TaskList struct","ref":"TaskValidator.Validators.ValidatorBehaviour.html#module-context"},{"type":"behaviour","title":"Error Handling - TaskValidator.Validators.ValidatorBehaviour","doc":"Validators should return structured ValidationError structs with:\n- `:type` - Atom identifying the error type\n- `:message` - Human-readable error description\n- `:task_id` - ID of the task being validated\n- `:line_number` - Location in the source document (if available)\n- `:details` - Additional error-specific information (optional)","ref":"TaskValidator.Validators.ValidatorBehaviour.html#module-error-handling"},{"type":"function","title":"TaskValidator.Validators.ValidatorBehaviour.get_priority/1","doc":"Gets the priority for a validator module.\n\nIf the module implements the priority/0 callback, uses that value.\nOtherwise returns the default priority of 50.","ref":"TaskValidator.Validators.ValidatorBehaviour.html#get_priority/1"},{"type":"callback","title":"TaskValidator.Validators.ValidatorBehaviour.priority/0","doc":"Optional callback to specify the validation priority.\n\nValidators with higher priority values run first. This allows\ncritical validations (like ID format) to run before more complex\nvalidations that might depend on basic task structure.\n\nDefault priority is 50 if not implemented.","ref":"TaskValidator.Validators.ValidatorBehaviour.html#c:priority/0"},{"type":"callback","title":"Returns - TaskValidator.Validators.ValidatorBehaviour.priority/0","doc":"- `non_neg_integer()` - Priority value (higher runs first)","ref":"TaskValidator.Validators.ValidatorBehaviour.html#c:priority/0-returns"},{"type":"callback","title":"TaskValidator.Validators.ValidatorBehaviour.validate/2","doc":"Validates a single task according to the validator's rules.","ref":"TaskValidator.Validators.ValidatorBehaviour.html#c:validate/2"},{"type":"callback","title":"Parameters - TaskValidator.Validators.ValidatorBehaviour.validate/2","doc":"- `task` - The Task struct to validate\n  - `context` - Map containing validation context (config, all_tasks, etc.)","ref":"TaskValidator.Validators.ValidatorBehaviour.html#c:validate/2-parameters"},{"type":"callback","title":"Returns - TaskValidator.Validators.ValidatorBehaviour.validate/2","doc":"- `ValidationResult.t()` - Success or failure with error details","ref":"TaskValidator.Validators.ValidatorBehaviour.html#c:validate/2-returns"},{"type":"module","title":"TaskValidator.Validators.ValidatorPipeline","doc":"Provides a pipeline for running multiple validators on tasks in priority order.\n\nThis module coordinates the execution of validator modules, ensuring they run\nin the correct order based on their priority values and providing aggregated\nvalidation results.","ref":"TaskValidator.Validators.ValidatorPipeline.html"},{"type":"module","title":"Usage - TaskValidator.Validators.ValidatorPipeline","doc":"validators = [\n      TaskValidator.Validators.IdValidator,\n      TaskValidator.Validators.StatusValidator,\n      TaskValidator.Validators.SectionValidator\n    ]\n    \n    context = %{\n      config: TaskValidator.Config.get_all(),\n      all_tasks: task_list.tasks,\n      references: task_list.references\n    }\n    \n    result = ValidatorPipeline.validate_task(task, validators, context)","ref":"TaskValidator.Validators.ValidatorPipeline.html#module-usage"},{"type":"module","title":"Priority Ordering - TaskValidator.Validators.ValidatorPipeline","doc":"Validators are automatically sorted by priority (highest first) before execution.\nThis ensures that fundamental validations (like ID format) run before more\ncomplex validations that might depend on basic task structure.","ref":"TaskValidator.Validators.ValidatorPipeline.html#module-priority-ordering"},{"type":"module","title":"Error Aggregation - TaskValidator.Validators.ValidatorPipeline","doc":"All validation errors and warnings from all validators are collected and\nreturned in a single ValidationResult. This provides complete feedback\nabout all validation issues rather than stopping at the first error.","ref":"TaskValidator.Validators.ValidatorPipeline.html#module-error-aggregation"},{"type":"module","title":"Early Exit - TaskValidator.Validators.ValidatorPipeline","doc":"If a validator returns a critical error (severity: :critical), the pipeline\nstops execution and returns immediately. This prevents cascading failures\nwhen fundamental validation fails.","ref":"TaskValidator.Validators.ValidatorPipeline.html#module-early-exit"},{"type":"function","title":"TaskValidator.Validators.ValidatorPipeline.default_validators/0","doc":"Gets the default set of validators for task validation.\n\nReturns the core validators that should be run for most validation scenarios.\nThe validators are automatically sorted by priority when used in validate_task/3.","ref":"TaskValidator.Validators.ValidatorPipeline.html#default_validators/0"},{"type":"function","title":"TaskValidator.Validators.ValidatorPipeline.validate_task/3","doc":"Validates a task using multiple validators in priority order.","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_task/3"},{"type":"function","title":"Parameters - TaskValidator.Validators.ValidatorPipeline.validate_task/3","doc":"- `task` - The Task struct to validate\n  - `validators` - List of validator modules that implement ValidatorBehaviour\n  - `context` - Map containing validation context (config, all_tasks, etc.)","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_task/3-parameters"},{"type":"function","title":"Returns - TaskValidator.Validators.ValidatorPipeline.validate_task/3","doc":"- `ValidationResult.t()` - Aggregated results from all validators","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_task/3-returns"},{"type":"function","title":"TaskValidator.Validators.ValidatorPipeline.validate_tasks/3","doc":"Validates multiple tasks using the same set of validators.\n\nThis is a convenience function for validating all tasks in a task list\nwith the same validator configuration.","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_tasks/3"},{"type":"function","title":"Parameters - TaskValidator.Validators.ValidatorPipeline.validate_tasks/3","doc":"- `tasks` - List of Task structs to validate\n  - `validators` - List of validator modules\n  - `context` - Map containing validation context","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_tasks/3-parameters"},{"type":"function","title":"Returns - TaskValidator.Validators.ValidatorPipeline.validate_tasks/3","doc":"- `ValidationResult.t()` - Aggregated results from all task validations","ref":"TaskValidator.Validators.ValidatorPipeline.html#validate_tasks/3-returns"},{"type":"module","title":"TaskValidator","doc":"Validates TaskList.md format compliance according to project guidelines.\n\nThe `TaskValidator` ensures that task documents follow a consistent structure,\nmaking it easier to track and manage work across multiple project components,\nwith a strong focus on error handling practices.","ref":"TaskValidator.html"},{"type":"module","title":"Validation Checks - TaskValidator","doc":"* ID format compliance (like SSH0001, SCP0001, ERR001, etc.)\n* Unique task IDs across the document\n* Required sections and fields present in each task, including Error Handling Guidelines\n* Different error handling requirements for main tasks and subtasks:\n  - Main tasks: Comprehensive error handling documentation with GenServer-specific examples\n  - Subtasks: Simplified error handling focused on task-specific approaches\n* Proper subtask structure with consistent prefixes\n* Valid status values from the allowed list\n* Proper review rating format for completed tasks\n* Error handling patterns and conventions","ref":"TaskValidator.html#module-validation-checks"},{"type":"module","title":"Error Handling Requirements - TaskValidator","doc":"Main tasks must include comprehensive error handling sections:\n\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\nSubtasks have a simplified error handling format:\n\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"TaskValidator.html#module-error-handling-requirements"},{"type":"module","title":"Usage Example - TaskValidator","doc":"case TaskValidator.validate_file(\"path/to/TaskList.md\") do\n      {:ok, message} ->\n        # Task list validation succeeded\n        IO.puts(\"Validation passed: \" <> message)\n      {:error, reason} ->\n        # Task list validation failed\n        IO.puts(\"Validation failed: \" <> reason)\n    end","ref":"TaskValidator.html#module-usage-example"},{"type":"function","title":"TaskValidator.validate_file/1","doc":"Validates a TaskList.md file for format compliance.\n\nThis is the main validation entry point that uses the new modular architecture\nwith dedicated parsers and individual validators.","ref":"TaskValidator.html#validate_file/1"},{"type":"function","title":"Parameters - TaskValidator.validate_file/1","doc":"- `file_path`: Path to the TaskList.md file to validate","ref":"TaskValidator.html#validate_file/1-parameters"},{"type":"function","title":"Returns - TaskValidator.validate_file/1","doc":"- `{:ok, message}` if validation passes\n- `{:error, error_message}` if validation fails","ref":"TaskValidator.html#validate_file/1-returns"},{"type":"function","title":"Examples - TaskValidator.validate_file/1","doc":"iex> TaskValidator.validate_file(\"docs/TaskList.md\")\n    {:ok, \"TaskList.md validation passed!\"}\n\n    iex> TaskValidator.validate_file(\"invalid_tasklist.md\")\n    {:error, \"Invalid task ID format for: INVALID. Expected pattern: ...\"}","ref":"TaskValidator.html#validate_file/1-examples"},{"type":"function","title":"TaskValidator.validate_file_detailed/1","doc":"Alternative validation function that returns detailed ValidationResult.\n\nThis provides more detailed validation information including warnings\nand structured error data for programmatic use.","ref":"TaskValidator.html#validate_file_detailed/1"},{"type":"function","title":"TaskValidator.validate_file_with_pipeline/2","doc":"Validates a file using the new validation pipeline with options.\n\nThis function provides more control over the validation process and\nreturns detailed validation results.","ref":"TaskValidator.html#validate_file_with_pipeline/2"},{"type":"function","title":"Parameters - TaskValidator.validate_file_with_pipeline/2","doc":"- `file_path`: Path to the TaskList.md file to validate\n- `options`: Keyword list of validation options (optional)","ref":"TaskValidator.html#validate_file_with_pipeline/2-parameters"},{"type":"function","title":"Options - TaskValidator.validate_file_with_pipeline/2","doc":"- `:strict` - Enable strict validation mode (default: false)\n- `:validators` - List of specific validators to run (default: all)","ref":"TaskValidator.html#validate_file_with_pipeline/2-options"},{"type":"function","title":"Returns - TaskValidator.validate_file_with_pipeline/2","doc":"- `{:ok, ValidationResult.t()}` with detailed validation information\n- `{:error, String.t()}` if file reading or parsing fails","ref":"TaskValidator.html#validate_file_with_pipeline/2-returns"},{"type":"task","title":"mix task_validator.create_template","doc":"Creates a template TaskList.md file with example tasks.\n\nThis task generates a new TaskList.md file with example tasks that follow\nthe required structure and format specifications. Use this as a starting\npoint for your own task list.","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html"},{"type":"task","title":"Usage - mix task_validator.create_template","doc":"mix task_validator.create_template [OPTIONS]","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-usage"},{"type":"task","title":"Options - mix task_validator.create_template","doc":"--path       Path where to create the TaskList.md file (default: ./TaskList.md)\n    --prefix     Project prefix for example tasks (default: PRJ)\n    --category   Task category to generate template for (default: phoenix_web)\n    --semantic   Use semantic prefixes instead of custom prefix","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-options"},{"type":"task","title":"Categories - mix task_validator.create_template","doc":"Each category generates a template tailored for specific development areas:\n\n    * otp_genserver    - OTP/GenServer development (processes, supervisors, state management)\n    * phoenix_web      - Phoenix web development (LiveView, controllers, routes)\n    * business_logic   - Phoenix contexts and domain logic (CRUD operations, validations)\n    * data_layer       - Ecto schemas and database design (migrations, queries)\n    * infrastructure   - Deployment and DevOps (releases, monitoring, configuration)\n    * testing          - Test implementation (unit tests, integration, property-based)","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-categories"},{"type":"task","title":"Semantic Prefixes - mix task_validator.create_template","doc":"When using --semantic, the following domain-specific prefixes are used:\n\n    * OTP - OTP/GenServer tasks\n    * PHX - Phoenix web tasks\n    * CTX - Context/business logic tasks\n    * DB  - Database/Ecto tasks\n    * INF - Infrastructure tasks\n    * TST - Testing tasks","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-semantic-prefixes"},{"type":"task","title":"Examples - mix task_validator.create_template","doc":"# Generate default Phoenix web template\n    mix task_validator.create_template\n\n    # Generate OTP template with custom prefix\n    mix task_validator.create_template --path ./docs/TaskList.md --prefix SSH --category otp_genserver\n\n    # Generate testing template with semantic prefix (TST)\n    mix task_validator.create_template --category testing --semantic\n\n    # Generate all templates in a directory\n    for cat in otp_genserver phoenix_web business_logic data_layer infrastructure testing; do\n      mix task_validator.create_template --category $cat --path docs/$cat.md\n    done","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-examples"},{"type":"task","title":"Template Features - mix task_validator.create_template","doc":"All generated templates include:\n\n    * Main tasks demonstrating \"In Progress\" status with subtasks\n    * Numbered subtasks with full sections (Status, Error Handling)\n    * Checkbox subtasks for minor items (phoenix_web and data_layer templates)\n    * Completed task examples with all required sections\n    * Proper use of the reference system ({{error-handling}}, {{test-requirements}}, etc.)\n    * Category-specific sections and requirements\n\nThe generated templates are guaranteed to pass validation.","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-template-features"},{"type":"function","title":"Mix.Tasks.TaskValidator.CreateTemplate.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#run/1"},{"type":"task","title":"mix validate_tasklist","doc":"Validates the format and structure of a TaskList.md file.","ref":"Mix.Tasks.ValidateTasklist.html"},{"type":"task","title":"Usage - mix validate_tasklist","doc":"mix validate_tasklist [OPTIONS]","ref":"Mix.Tasks.ValidateTasklist.html#module-usage"},{"type":"task","title":"Options - mix validate_tasklist","doc":"--path       Path to the TaskList.md file (default: ./TaskList.md)","ref":"Mix.Tasks.ValidateTasklist.html#module-options"},{"type":"task","title":"Examples - mix validate_tasklist","doc":"# Validate default TaskList.md in current directory\n    mix validate_tasklist\n\n    # Validate specific file\n    mix validate_tasklist --path docs/TaskList.md\n\n    # Validate example templates\n    mix validate_tasklist --path docs/examples/phoenix_web_example.md","ref":"Mix.Tasks.ValidateTasklist.html#module-examples"},{"type":"task","title":"Task List Structure - mix validate_tasklist","doc":"The task list must contain:\n- **Current Tasks** table (active tasks)\n- **Completed Tasks** table (finished tasks)\n- **Task Details** sections for each task","ref":"Mix.Tasks.ValidateTasklist.html#module-task-list-structure"},{"type":"task","title":"Validation Rules - mix validate_tasklist","doc":"","ref":"Mix.Tasks.ValidateTasklist.html#module-validation-rules"},{"type":"task","title":"Task ID Format - mix validate_tasklist","doc":"- 2-4 uppercase letters as prefix (e.g., SSH, SCP, ERR)\n- 3-4 digits as sequence number (e.g., 001, 0001)\n- Optional subtask suffix: hyphen + number for numbered subtasks (e.g., SSH0001-1)\n- Optional subtask suffix: letter for checkbox subtasks (e.g., SSH0001a)\n- Examples: SSH0001, SCP0001, ERR001, SSH0001-1, SSH0001a","ref":"Mix.Tasks.ValidateTasklist.html#module-task-id-format"},{"type":"task","title":"Status Values - mix validate_tasklist","doc":"- **Planned** - Task not yet started\n- **In Progress** - Active work (requires subtasks)\n- **Review** - Under review\n- **Completed** - Finished (requires additional sections)\n- **Blocked** - Work blocked","ref":"Mix.Tasks.ValidateTasklist.html#module-status-values"},{"type":"task","title":"Priority Values - mix validate_tasklist","doc":"- **Critical** - Must be done immediately\n- **High** - Important, should be prioritized\n- **Medium** - Normal priority\n- **Low** - Can be deferred","ref":"Mix.Tasks.ValidateTasklist.html#module-priority-values"},{"type":"task","title":"Error Handling Requirements - mix validate_tasklist","doc":"Main tasks and subtasks have different error handling requirements:\n\n#### Main Tasks\nMust include comprehensive error handling documentation:\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\n#### Subtasks\nUse simplified error handling format:\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"Mix.Tasks.ValidateTasklist.html#module-error-handling-requirements"},{"type":"task","title":"Common Validation Errors: - mix validate_tasklist","doc":"- Using wrong error handling format (e.g., main task format for subtasks)\n- Missing error handling sections\n- Incomplete error handling documentation","ref":"Mix.Tasks.ValidateTasklist.html#module-common-validation-errors"},{"type":"task","title":"Required Sections - mix validate_tasklist","doc":"#### Main Tasks\nAll main tasks must include these sections:\n- **Description** - What the task accomplishes\n- **Status** - Current state (Planned, In Progress, etc.)\n- **Priority** - Task importance (Critical, High, Medium, Low)\n- **Dependencies** - Other tasks that must be completed first (or \"None\")\n- **Error Handling** - Comprehensive error handling documentation\n- Test sections: ExUnit Test Requirements, Integration Test Scenarios\n- TypeSpec sections: Requirements, Documentation, Verification\n- Code Quality KPIs - Metrics for code quality\n\nAdditional sections for specific categories:\n- **OTP tasks**: Process Design, State Management, Supervision Strategy\n- **Phoenix tasks**: Route Design, Context Integration, Template/Component Strategy\n- **Data tasks**: Schema Design, Migration Strategy, Query Optimization\n- **Business logic**: Context Boundaries, Business Rules\n\n#### Completed Tasks\nCompleted tasks require additional sections:\n- **Implementation Notes** - How it was implemented\n- **Complexity Assessment** - Implementation complexity\n- **Maintenance Impact** - Long-term maintenance considerations\n- **Error Handling Implementation** - How errors were handled\n- **Review Rating** - Quality score (1-5)","ref":"Mix.Tasks.ValidateTasklist.html#module-required-sections"},{"type":"task","title":"Subtask Requirements - mix validate_tasklist","doc":"- Must use same prefix as parent task\n- Must have \"Status\" section\n- If status is \"Completed\", must have \"Review Rating\"\n- Review rating format: 1-5 with optional decimal (e.g., 4.5)\n- Review rating can include \"(partial)\" suffix\n- Can be organized as checkboxes or numbered entries","ref":"Mix.Tasks.ValidateTasklist.html#module-subtask-requirements"},{"type":"task","title":"Subtask Formats - mix validate_tasklist","doc":"Tasks can organize subtasks in two formats:\n\n#### 1. Checkbox Format (for minor items)\nSimple checklist format for quick subtasks:\n```markdown\n**Subtasks**\n- [x] Basic structure implementation [SSH0001a]\n- [ ] Essential features [SSH0001b]\n- [ ] Integration testing [SSH0001c]\n```\n\n#### 2. Numbered Format (for major subtasks)\nFull format with sections for significant subtasks:\n```markdown\n#### 1. Basic structure implementation (SSH0001-1)\n**Description**\nImplement the core structure with proper error handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n\n\\{\\{error-handling-subtask\\}\\}\n```\n\nUse numbered format when subtasks need detailed tracking, checkbox format for simple items.","ref":"Mix.Tasks.ValidateTasklist.html#module-subtask-formats"},{"type":"task","title":"Additional Rules - mix validate_tasklist","doc":"- Tasks marked as \"In Progress\" must have at least one subtask\n- All non-completed tasks must have detailed entries\n- No duplicate task IDs allowed\n- All subtasks must use the same prefix as their parent task","ref":"Mix.Tasks.ValidateTasklist.html#module-additional-rules"},{"type":"task","title":"Reference System - mix validate_tasklist","doc":"The validator supports content references to reduce file size by 60-70%:\n- Define references: `## #\\{\\{reference-name\\}\\}`\n- Use references: `\\{\\{reference-name\\}\\}`\n- Common references: \\{\\{error-handling\\}\\}, \\{\\{test-requirements\\}\\}, \\{\\{standard-kpis\\}\\}\n- The validator only checks existence, not content","ref":"Mix.Tasks.ValidateTasklist.html#module-reference-system"},{"type":"task","title":"Common Validation Errors - mix validate_tasklist","doc":"1. **Wrong error handling format** - Using main task format for subtasks\n2. **Missing subtasks** - \"In Progress\" tasks without subtasks\n3. **Prefix mismatch** - Subtask ID doesn't match parent prefix\n4. **Invalid status** - Using non-standard status values\n5. **Missing sections** - Required sections not present\n6. **Invalid review rating** - Wrong format or out of range","ref":"Mix.Tasks.ValidateTasklist.html#module-common-validation-errors-1"},{"type":"task","title":"See Also - mix validate_tasklist","doc":"- Run `mix help task_validator.create_template` to generate templates\n- Check `docs/examples/` for complete working examples\n- See `README.md` for detailed documentation","ref":"Mix.Tasks.ValidateTasklist.html#module-see-also"},{"type":"task","title":"Example - mix validate_tasklist","doc":"mix validate_tasklist\n    mix validate_tasklist --path ./custom/path/TaskList.md","ref":"Mix.Tasks.ValidateTasklist.html#module-example"},{"type":"function","title":"Mix.Tasks.ValidateTasklist.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.ValidateTasklist.html#run/1"},{"type":"extras","title":"TaskValidator","doc":"# TaskValidator\n\nA library for validating Markdown task lists against a structured format specification, with enhanced support for Elixir/Phoenix projects.","ref":"readme.html"},{"type":"extras","title":"Installation - TaskValidator","doc":"Add `task_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:task_validator, \"~> 0.9.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - TaskValidator","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Command Line - TaskValidator","doc":"```bash\n# Validate the default TaskList.md file\nmix validate_tasklist\n\n# Validate a custom file path\nmix validate_tasklist --path ./path/to/custom/TaskList.md\n\n# Create a new task list template\nmix task_validator.create_template\n\n# Create a template with custom prefix\nmix task_validator.create_template --prefix SSH\n\n# Create a template for a specific category (Elixir/Phoenix categories)\nmix task_validator.create_template --category otp_genserver\nmix task_validator.create_template --category phoenix_web\nmix task_validator.create_template --category testing\n\n# Use semantic prefixes automatically\nmix task_validator.create_template --semantic --category phoenix_web\n```","ref":"readme.html#command-line"},{"type":"extras","title":"Programmatic - TaskValidator","doc":"```elixir\n# Simple validation\ncase TaskValidator.validate_file(\"path/to/tasklist.md\") do\n  {:ok, message} ->\n    IO.puts(\"Success: #{message}\")\n  {:error, reason} ->\n    IO.puts(\"Error: #{reason}\")\nend\n\n# Detailed validation with custom validators\nvalidators = [\n  TaskValidator.Validators.IdValidator,\n  TaskValidator.Validators.StatusValidator,\n  TaskValidator.Validators.KpiValidator\n]\n\ncase TaskValidator.validate_file_with_pipeline(\"path/to/tasklist.md\", validators) do\n  {:ok, result} ->\n    IO.puts(\"Valid: #{result.valid?}\")\n    IO.puts(\"Warnings: #{length(result.warnings)}\")\n  {:error, reason} ->\n    IO.puts(\"Error: #{reason}\")\nend\n```","ref":"readme.html#programmatic"},{"type":"extras","title":"Configuration - TaskValidator","doc":"TaskValidator supports extensive configuration options. You can customize validation rules by adding settings to your `config/config.exs`:\n\n```elixir\nconfig :task_validator,\n  valid_statuses: [\"Todo\", \"Doing\", \"Done\"],\n  max_functions_per_module: 7,\n  max_lines_per_function: 20\n```\n\nSee the [Configuration Guide](guides/configuration.md) for all available options.","ref":"readme.html#configuration"},{"type":"extras","title":"Format Specification - TaskValidator","doc":"The TaskValidator enforces a specific format for task lists with a strong focus on error handling:\n\n- Task IDs must follow a consistent pattern: 2-4 uppercase letters followed by 3-4 digits (e.g., SSH0001, SCP0001, ERR001, REF0002)\n- Subtasks use numeric suffixes (SSH0001-1, SSH0001-2, etc.)\n- Checkbox format is recommended for subtasks: `- [x] Completed task [SSH0001-1]` or `- [ ] Pending task [SSH0001-2]`\n- Dependencies field tracks relationships between tasks\n- Code Quality KPIs with complexity-based limits:\n  * Base limits: max 8 functions/module, 15 lines/function, call depth 3\n  * Complexity multipliers: Simple (1x), Medium (1.5x), Complex (2x), Critical (3x)\n  * Categories have default complexity levels (e.g., Testing: Complex)\n- Task categories for Elixir/Phoenix projects:\n  * OTP/GenServer: 1-99 (OTP, GEN, SUP prefixes)\n  * Phoenix Web: 100-199 (PHX, WEB, LV prefixes)\n  * Business Logic: 200-299 (CTX, BIZ, DOM prefixes)\n  * Data Layer: 300-399 (DB, ECT, MIG prefixes)\n  * Infrastructure: 400-499 (INF, DEP, ENV prefixes)\n  * Testing: 500-599 (TST, TES, INT prefixes)\n- Main tasks and subtasks have different error handling section requirements:\n  * Main tasks: Comprehensive error handling documentation including GenServer specifics\n  * Subtasks: Simplified error handling focused on task-specific approaches\n- Other required sections include Description, Status, Priority, Dependencies, etc.\n- Tasks marked as \"In Progress\" must have subtasks\n- Review ratings must follow the specified format (1-5 scale)\n- Support for reference definitions to reduce repetition by 60-70% (e.g., {{error-handling}}, {{test-requirements}})","ref":"readme.html#format-specification"},{"type":"extras","title":"Error Handling Requirements - TaskValidator","doc":"Main tasks must include the following comprehensive error handling sections:\n\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\nSubtasks have a simplified error handling format:\n\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"readme.html#error-handling-requirements"},{"type":"extras","title":"Dependencies - TaskValidator","doc":"Tasks can specify dependencies on other tasks using the Dependencies field:\n\n```markdown\n**Dependencies**\n- SSH0001 (Authentication must be complete)\n- ERR001 (Error handling framework required)\n```\n\nThe validator ensures all referenced tasks exist in the task list.","ref":"readme.html#dependencies"},{"type":"extras","title":"Subtask Formats - TaskValidator","doc":"Subtasks can be organized in two formats:\n\n**Checkbox Format (Simplified):**\n```markdown","ref":"readme.html#subtask-formats"},{"type":"extras","title":"SSH0001: SSH Session Initialization - TaskValidator","doc":"**Subtasks**\n- [x] Implement password authentication [SSH0001a]\n- [ ] Add key-based authentication [SSH0001b]\n- [ ] Implement host verification [SSH0001c]\n```\n\nThis format provides immediate visual feedback on task progress and is ideal for minor subtasks or quick checklists.\n\n**Numbered Format (Full sections):**\n```markdown\n#### 1. Implement password authentication (SSH0001-1)\n**Description**\nCreate password-based authentication mechanism with secure credential handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n\n{{error-handling-subtask}}\n```\n\nThe numbered format is recommended for significant subtasks that need detailed tracking. Both formats are valid and can be mixed within the same task list. See `docs/examples/` for complete working examples demonstrating both formats.","ref":"readme.html#ssh0001-ssh-session-initialization"},{"type":"extras","title":"Code Quality KPIs - TaskValidator","doc":"All tasks must include code quality metrics that adhere to these limits:\n- Maximum functions per module: 5\n- Maximum lines per function: 15\n- Maximum call depth: 2\n\n```markdown\n**Code Quality KPIs**\n- Functions per module: 3\n- Lines per function: 12\n- Call depth: 2\n```","ref":"readme.html#code-quality-kpis"},{"type":"extras","title":"Reference Definitions (Content Placeholders) - TaskValidator","doc":"References are a powerful feature to reduce file size by 60-70% while maintaining consistency. They work as content placeholders that the validator recognizes but doesn't expand.\n\nDefine references at the end of your task list:\n\n```markdown","ref":"readme.html#reference-definitions-content-placeholders"},{"type":"extras","title":"References - TaskValidator","doc":"## #{{error-handling}}\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n\n## #{{standard-kpis}}\n**Code Quality KPIs**\n- Functions per module: ≤ 10\n- Lines per function: ≤ 20\n- Call depth: ≤ 3\n```\n\nThen use them in tasks with `{{reference-name}}`:\n\n```markdown","ref":"readme.html#references"},{"type":"extras","title":"SSH0001: Implement SSH connection module - TaskValidator","doc":"**Description**: Create core SSH connection module\n**Requirements**: TCP connection, SSH handshake\n{{test-requirements}}\n{{typespec-requirements}}\n{{def-no-dependencies}}\n{{standard-kpis}}\n{{error-handling}}\n**Status**: In Progress\n**Priority**: High\n```\n\nKey points about references:\n- **Definition format**: `## #{{reference-name}}` (note the `#`)\n- **Usage format**: `{{reference-name}}` (no `#`)\n- **Common references**: `{{error-handling}}`, `{{error-handling-subtask}}`, `{{test-requirements}}`, `{{typespec-requirements}}`, `{{standard-kpis}}`, `{{def-no-dependencies}}`\n- **Validation**: The validator only checks that references exist, expansion is done by AI tools\n- **Flexibility**: References can replace entire sections or multiple sections at once\n\nSee `/docs/example_tasklist_with_references.md` for a complete working example.","ref":"readme.html#ssh0001-implement-ssh-connection-module"},{"type":"extras","title":"Task Categories - TaskValidator","doc":"For Elixir/Phoenix projects, tasks are organized into semantic categories:\n\n| Category | ID Range | Prefix | Description |\n| --- | --- | --- | --- |\n| OTP/GenServer | 0001-0099 | OTP | Process management, supervisors, state machines |\n| Phoenix Web | 0100-0199 | PHX | Controllers, LiveView, routes, plugs |\n| Business Logic | 0200-0299 | CTX | Contexts, domain logic, business rules |\n| Data Layer | 0300-0399 | DB | Schemas, migrations, queries, repos |\n| Infrastructure | 0400-0499 | INF | Deployment, monitoring, configuration |\n| Testing | 0500-0599 | TST | Test implementation, coverage, CI/CD |\n\nEach category has specific required sections tailored to its domain. For example:\n- **OTP tasks**: Process Design, State Management, Supervision Strategy\n- **Phoenix tasks**: Route Design, Context Integration, Template/Component Strategy\n- **Data tasks**: Schema Design, Migration Strategy, Query Optimization","ref":"readme.html#task-categories"},{"type":"extras","title":"Multi-Project Support - TaskValidator","doc":"The task validator supports multiple project prefixes in the same task list. Each prefix typically represents a different component or subproject:\n\n```markdown","ref":"readme.html#multi-project-support"},{"type":"extras","title":"Current Tasks - TaskValidator","doc":"| ID      | Description          | Status      | Priority |\n| ------- | -------------------- | ----------- | -------- |\n| SSH0001 | SSH authentication   | In Progress | High     |\n| SCP0001 | File transfer module | Planned     | Medium   |\n| ERR001  | Error handling       | In Progress | High     |\n```\n\nThe validator ensures consistency within each task hierarchy, so a task with ID \"SSH0001\" must have subtasks with IDs like \"SSH0001-1\", \"SSH0001-2\", etc.","ref":"readme.html#current-tasks"},{"type":"extras","title":"Example Files - TaskValidator","doc":"The repository includes several example files:","ref":"readme.html#example-files"},{"type":"extras","title":"Complete Task List Examples (docs/examples/) - TaskValidator","doc":"Full working examples for different project categories:\n\n- `otp_genserver_example.md` - OTP/GenServer tasks with supervision patterns\n- `phoenix_web_example.md` - Phoenix web development tasks (LiveView, controllers)\n- `business_logic_example.md` - Phoenix contexts and business logic tasks\n- `data_layer_example.md` - Ecto schemas and database design tasks\n- `infrastructure_example.md` - Deployment and infrastructure tasks\n- `testing_example.md` - Comprehensive testing strategy tasks\n\nEach example demonstrates proper subtask formatting, including both numbered subtasks with full sections and checkbox format for minor items. See `docs/examples/README.md` for detailed explanations.","ref":"readme.html#complete-task-list-examples-docs-examples"},{"type":"extras","title":"Documentation - TaskValidator","doc":"- [Configuration Guide](guides/configuration.md) - Detailed configuration options\n- [Writing Compliant Tasks](guides/writing_compliant_tasks.md) - How to write valid task lists\n- [Sample Task List](guides/sample_tasklist.md) - Complete example demonstrating all features\n- [Examples Directory](docs/examples/) - Category-specific examples for all 6 categories\n- [LLM Instructions](llm.txt) - Machine-readable guide for AI assistants","ref":"readme.html#documentation"},{"type":"extras","title":"Test Fixtures (test/fixtures/) - TaskValidator","doc":"Validation test cases:\n\n- `sample_tasklist.md` - A basic valid task list\n- `multi_prefix_tasklist.md` - A valid task list with multiple project prefixes\n- `prefix_mismatch.md` - Demonstrates prefix mismatch validation (subtask has different prefix than parent)\n- `invalid_rating.md` - Shows validation of review rating format\n- `invalid_mix_prefixes.md` - Contains various validation errors\n\nYou can test validation against these examples:\n\n```bash\nmix validate_tasklist --path test/fixtures/multi_prefix_tasklist.md  # Should pass\nmix validate_tasklist --path test/fixtures/prefix_mismatch.md        # Should fail\n```","ref":"readme.html#test-fixtures-test-fixtures"},{"type":"extras","title":"License - TaskValidator","doc":"MIT License\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.9.5 (2025-01-20) - Changelog","doc":"","ref":"changelog.html#v0-9-5-2025-01-20"},{"type":"extras","title":"Fixed - Changelog","doc":"- **KPI Validator Compilation** - Fixed regex pattern compilation error\n  - Moved regex patterns from module attributes to runtime function\n  - Resolves ArgumentError when compiling with Elixir 1.19.0+\n  - Prevents \"cannot inject attribute into function/macro\" errors\n  - No changes to validation behavior - internal implementation fix only","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.9.4 (2025-01-06) - Changelog","doc":"","ref":"changelog.html#v0-9-4-2025-01-06"},{"type":"extras","title":"Improved - Changelog","doc":"- **Markdown Parser Enhancement** - Support for flexible task header formats\n  - Now accepts both `###` and `####` (3 or 4 hashes) for task headers\n  - Enables validation of task lists with different markdown formatting styles\n  - Fixes compatibility with projects using 4-hash headers for task details","ref":"changelog.html#improved"},{"type":"extras","title":"v0.9.3 (2025-06-05) - Changelog","doc":"","ref":"changelog.html#v0-9-3-2025-06-05"},{"type":"extras","title":"Added - Changelog","doc":"- **llm.txt** - Machine-readable instructions for LLMs\n  - Comprehensive guide for AI assistants using the library\n  - Quick reference for validation rules and formats\n  - Common error solutions and best practices\n  - API usage examples and patterns","ref":"changelog.html#added"},{"type":"extras","title":"Improved - Changelog","doc":"- **Test Requirements Philosophy** - Emphasize integration-first testing\n  - Updated all test requirement references to promote testing against real dependencies first\n  - Document actual behavior before creating mocks\n  - Extract unit tests from integration test observations\n  - Emphasizes that unrealistic mocks are worse than no tests","ref":"changelog.html#improved-1"},{"type":"extras","title":"v0.9.2 (2025-06-05) - Changelog","doc":"","ref":"changelog.html#v0-9-2-2025-06-05"},{"type":"extras","title":"Added - Changelog","doc":"- **llm.txt** - Machine-readable instructions for LLMs\n  - Comprehensive guide for AI assistants using the library\n  - Quick reference for validation rules and formats\n  - Common error solutions and best practices\n  - API usage examples and patterns","ref":"changelog.html#added-1"},{"type":"extras","title":"v0.9.2 (2025-06-05) - Not Published - Changelog","doc":"_Skipped due to Hex.pm publication timing - all changes included in v0.9.3_","ref":"changelog.html#v0-9-2-2025-06-05-not-published"},{"type":"extras","title":"v0.9.1 (2025-06-05) - Changelog","doc":"","ref":"changelog.html#v0-9-1-2025-06-05"},{"type":"extras","title":"Added - Changelog","doc":"- **BUG001 Fix**: Corrected subtask content parsing in MarkdownParser\n  - Subtasks now properly capture all content between headers\n  - Both numbered (#### format) and checkbox formats work correctly\n  \n- **BUG002 Fix**: Enhanced all templates with proper subtask examples  \n  - All 6 category templates now include comprehensive subtask demonstrations\n  - Templates show both numbered and checkbox subtask formats\n  - Parent tasks with subtasks correctly show \"In Progress\" status\n  - All templates now pass validation\n\n- **Mix Task Improvements**\n  - Created Mix.Tasks.TaskValidator as main entry point\n  - Enhanced help documentation with detailed examples\n  - Fixed naming inconsistency (all tasks now appear in `mix help`)\n  - Added @shortdoc attributes for better discoverability","ref":"changelog.html#added-2"},{"type":"extras","title":"Fixed - Changelog","doc":"- Subtask content extraction not capturing full content between headers\n- Template generation missing proper subtask examples\n- Confusing Mix task naming structure  \n- Missing documentation files referenced in README and mix.exs","ref":"changelog.html#fixed-1"},{"type":"extras","title":"Documentation - Changelog","doc":"- Recreated missing guides/ directory with comprehensive documentation\n- Updated CHANGELOG to reflect actual project state\n- Fixed broken references throughout the codebase","ref":"changelog.html#documentation"},{"type":"extras","title":"v0.9.0 (2025-06-04) - Changelog","doc":"","ref":"changelog.html#v0-9-0-2025-06-04"},{"type":"extras","title":"Features - Changelog","doc":"- **Major Architecture Refactoring** - Transformed monolithic validator into modular pipeline architecture\n  - Split parsing and validation into separate concerns (MarkdownParser, ReferenceResolver, TaskExtractor)\n  - Created 8 specialized validators with behavior-based interface\n  - Added ValidationPipeline for coordinated validation with priority ordering\n  - New API functions: `validate_file_with_pipeline/2` and `validate_file_detailed/1`\n  - Maintains 100% backward compatibility with existing `validate_file/1` API\n\n- **Enhanced Elixir/Phoenix Support** - Added specialized validation for Elixir/Phoenix projects\n  - 6 semantic task categories with ID ranges (OTP: 1-99, Phoenix: 100-199, etc.)\n  - Category-specific required sections and validation rules\n  - Elixir-specific KPIs (GenServer state complexity, Phoenix context boundaries, Ecto query complexity)\n  - Enhanced error handling templates for each category\n\n- **Complexity-Based KPI Validation** - Flexible code quality limits based on task complexity\n  - Tasks can specify `**Complexity Assessment**: Simple|Medium|Complex|Critical`\n  - Complexity levels apply multipliers to base KPI limits:\n    - Simple: 1x (default)\n    - Medium: 1.5x\n    - Complex: 2x\n    - Critical: 3x\n  - Categories have default complexity levels:\n    - Testing: Complex (extensive test scenarios)\n    - Infrastructure: Complex (deployment complexity)\n    - OTP/GenServer: Medium (state management)\n    - Phoenix Web: Simple (thin controllers)\n    - Business Logic: Medium (domain complexity)\n    - Data Layer: Simple (straightforward schemas)\n  - KpiValidator automatically determines category from task ID when category not set","ref":"changelog.html#features"},{"type":"extras","title":"Documentation - Changelog","doc":"- Created comprehensive guides/ directory with:\n  - configuration.md - How to configure TaskValidator\n  - writing_compliant_tasks.md - Complete guide for writing valid task lists\n  - sample_tasklist.md - Full example demonstrating all features\n- Created docs/examples/ directory with 6 category-specific examples\n- Added docs/examples/README.md explaining subtask formats\n- Updated main README with clearer documentation structure\n- Added multiple Elixir/Phoenix-specific examples","ref":"changelog.html#documentation-1"},{"type":"extras","title":"Internal Improvements - Changelog","doc":"- Achieved 100% test coverage (165 tests, all passing)\n- Clean separation of concerns across 15+ focused modules\n- Extensible validator pipeline supporting custom validators\n- Improved error messages with detailed context","ref":"changelog.html#internal-improvements"},{"type":"extras","title":"Known Issues - Changelog","doc":"- Some category templates (phoenix_web, business_logic, data_layer) may have minor validation issues when generated. These templates work but may need manual adjustments. This will be fixed in a patch release.","ref":"changelog.html#known-issues"},{"type":"extras","title":"v0.8.1 (2025-05-28) - Changelog","doc":"","ref":"changelog.html#v0-8-1-2025-05-28"},{"type":"extras","title":"Documentation - Changelog","doc":"- Added missing `guides/configuration.md` file that was referenced in README\n- Fixed hex docs warning about missing file reference\n- Added configuration guide to mix.exs docs extras list","ref":"changelog.html#documentation-2"},{"type":"extras","title":"v0.8.0 (2025-05-28) - Changelog","doc":"","ref":"changelog.html#v0-8-0-2025-05-28"},{"type":"extras","title":"Features - Changelog","doc":"- Added configurable validation system allowing users to customize validation parameters\n  - All hardcoded values are now configurable via Application environment\n  - New `TaskValidator.Config` module provides centralized configuration access\n  - Configurable parameters include:\n    - Valid statuses and priorities\n    - Task ID regex pattern and rating regex\n    - Code quality KPI thresholds (max functions, lines, call depth)\n    - Task category ranges for organizing task numbers\n  - Configuration validation ensures only valid values are accepted\n  - Comprehensive configuration guide added at `guides/configuration.md`","ref":"changelog.html#features-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed test isolation issues by properly clearing Application configuration between tests\n- Added setup blocks to ensure clean configuration state for each test run","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.7.1 (2025-01-28) - Changelog","doc":"","ref":"changelog.html#v0-7-1-2025-01-28"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed test fixture files to comply with validation requirements\n  - Added missing reference definitions in `reference_test.md`\n  - Added required **Architecture Notes** and **Complexity Assessment** sections to core category tasks\n  - Fixed reference examples in comments to avoid validation conflicts\n  - Added missing required sections (Simplicity Principle, TypeSpec requirements, etc.) to various test fixtures\n- All 31 tests now pass successfully","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"v0.7.0 (2025-05-25) - Changelog","doc":"","ref":"changelog.html#v0-7-0-2025-05-25"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Changed subtask ID format from letter suffixes to numeric suffixes (e.g., `SSH0001a` → `SSH0001-1`)\n- Updated reference syntax from `{{reference-name}}` to `#{{reference-name}}` for better clarity","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Features - Changelog","doc":"- Added checkbox format as the recommended approach for subtasks\n  - `- [x] Completed subtask [TASK0001-1]`\n  - `- [ ] Pending subtask [TASK0001-2]`\n- Both checkbox and numbered formats are now supported, with checkbox being recommended","ref":"changelog.html#features-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Updated all templates to use the new numeric subtask ID format\n- Enhanced documentation to show both subtask formats with clear recommendations\n- Updated mix help output to display the new checkbox format examples\n- Improved consistency across all documentation files","ref":"changelog.html#enhancements"},{"type":"extras","title":"Documentation - Changelog","doc":"- Updated `guides/writing_compliant_tasks.md` with new subtask format examples\n- Enhanced README.md to show checkbox format as recommended\n- Added comprehensive subtask format examples to mix task help","ref":"changelog.html#documentation-3"},{"type":"extras","title":"v0.6.0 (2025-05-23) - Changelog","doc":"","ref":"changelog.html#v0-6-0-2025-05-23"},{"type":"extras","title":"Features - Changelog","doc":"- Added support for checkbox-style subtasks (e.g., `- [ ] Subtask a [SSH0001a]`)\n- Added Dependencies field validation with cross-reference checking\n- Added Code Quality KPIs validation (max functions per module: 5, max lines per function: 15, max call depth: 2)\n- Added task category validation with predefined ranges:\n  - Core infrastructure: 1-99\n  - Features: 100-199\n  - Documentation: 200-299\n  - Testing: 300-399\n- Added category-specific required sections for different task types\n- Enhanced template generator with `--category` option for category-specific templates\n- Added reference definitions support to reduce repetition in task lists\n  - Define reusable content blocks with `","ref":"changelog.html#features-3"},{"type":"extras","title":"Reference Definitions` - Changelog","doc":"- Use references in tasks with `{{reference-name}}` syntax\n  - Templates now use references for error handling and KPIs\n  - Significantly reduces task list file size","ref":"changelog.html#reference-definitions"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Improved task ID regex to support letter suffixes for checkbox subtasks\n- Enhanced validation to ensure dependencies reference existing tasks\n- Added comprehensive category validation rules\n- Updated templates to include new required fields and sections","ref":"changelog.html#enhancements-1"},{"type":"extras","title":"v0.5.0 (2025-05-19) - Changelog","doc":"","ref":"changelog.html#v0-5-0-2025-05-19"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Changed error handling requirements: main tasks and subtasks now have different formats\n- Main tasks require comprehensive error handling with GenServer specifics\n- Subtasks use simplified error handling focused on task-specific approaches","ref":"changelog.html#breaking-changes-1"},{"type":"extras","title":"Documentation - Changelog","doc":"- Updated all documentation to reflect different error handling requirements\n- Added clear examples showing main task vs subtask error handling formats\n- Fixed test fixtures and templates to follow the new error handling patterns","ref":"changelog.html#documentation-4"},{"type":"extras","title":"v0.4.1 (2025-05-18) - Changelog","doc":"","ref":"changelog.html#v0-4-1-2025-05-18"},{"type":"extras","title":"Features - Changelog","doc":"- Added validation for completed tasks requiring implementation notes, complexity assessment, and maintenance impact\n- Enhanced documentation with examples of required completion sections\n- Updated guides with examples of compliant task documentation","ref":"changelog.html#features-4"},{"type":"extras","title":"v0.4.0 (2025-05-18) - Changelog","doc":"","ref":"changelog.html#v0-4-0-2025-05-18"},{"type":"extras","title":"Features - Changelog","doc":"- Added `mix create_template` task for generating new task list templates\n- Added `mix validate_tasklist` task for validating task lists\n- Improved CLI interface with better error handling and user feedback","ref":"changelog.html#features-5"},{"type":"extras","title":"v0.3.0 (2024-05-29) - Changelog","doc":"","ref":"changelog.html#v0-3-0-2024-05-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Improved module documentation\n- Better HexDocs integration\n- Added more examples and guides","ref":"changelog.html#enhancements-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed formatting issues in the validator\n- Improved error messages for better clarity","ref":"changelog.html#bug-fixes-2"},{"type":"extras","title":"v0.2.1 (2024-05-25) - Changelog","doc":"","ref":"changelog.html#v0-2-1-2024-05-25"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Added support for multi-project prefixes\n- Improved validation for subtask prefixes","ref":"changelog.html#enhancements-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed issue with partial review ratings","ref":"changelog.html#bug-fixes-3"},{"type":"extras","title":"v0.1.0 (2024-05-20) - Changelog","doc":"- Initial release\n- Basic task validation functionality\n- Command-line interface via mix task","ref":"changelog.html#v0-1-0-2024-05-20"},{"type":"extras","title":"Writing Compliant Tasks Guide","doc":"# Writing Compliant Tasks Guide\n\nThis guide explains how to write task lists that comply with TaskValidator's format specifications.","ref":"writing_compliant_tasks.html"},{"type":"extras","title":"Task List Structure - Writing Compliant Tasks Guide","doc":"Every task list must have three main sections:\n\n1. **Current Tasks** - Table of active tasks\n2. **Completed Tasks** - Table of finished tasks  \n3. **Task Details** - Detailed descriptions for each task","ref":"writing_compliant_tasks.html#task-list-structure"},{"type":"extras","title":"Task ID Format - Writing Compliant Tasks Guide","doc":"Task IDs follow a specific pattern:\n\n```\n[PREFIX][NUMBER][-SUBTASK]\n```\n\n- **PREFIX**: 2-4 uppercase letters (e.g., SSH, OTP, PHX)\n- **NUMBER**: 3-4 digits (e.g., 001, 0001)\n- **SUBTASK**: Optional suffix for subtasks\n  - Numbered: -1, -2, -3 (for detailed subtasks)\n  - Lettered: a, b, c (for checkbox subtasks)","ref":"writing_compliant_tasks.html#task-id-format"},{"type":"extras","title":"Examples - Writing Compliant Tasks Guide","doc":"- Main tasks: `SSH0001`, `PHX0101`, `DB0301`\n- Numbered subtasks: `SSH0001-1`, `SSH0001-2`\n- Checkbox subtasks: `SSH0001a`, `SSH0001b`","ref":"writing_compliant_tasks.html#examples"},{"type":"extras","title":"Semantic Prefixes - Writing Compliant Tasks Guide","doc":"For Elixir/Phoenix projects, use these semantic prefixes:\n\n| Category | Prefix | Range | Description |\n| --- | --- | --- | --- |\n| OTP/GenServer | OTP | 0001-0099 | Process and supervision |\n| Phoenix Web | PHX | 0100-0199 | Web layer tasks |\n| Business Logic | CTX | 0200-0299 | Contexts and domain |\n| Data Layer | DB | 0300-0399 | Ecto and database |\n| Infrastructure | INF | 0400-0499 | Deployment and ops |\n| Testing | TST | 0500-0599 | Test implementation |","ref":"writing_compliant_tasks.html#semantic-prefixes"},{"type":"extras","title":"Required Sections - Writing Compliant Tasks Guide","doc":"","ref":"writing_compliant_tasks.html#required-sections"},{"type":"extras","title":"Main Tasks - Writing Compliant Tasks Guide","doc":"Every main task must include these sections:\n\n```markdown","ref":"writing_compliant_tasks.html#main-tasks"},{"type":"extras","title":"TASK001: Task Title - Writing Compliant Tasks Guide","doc":"**Description**\nWhat this task accomplishes\n\n**Status**\nPlanned | In Progress | Review | Completed | Blocked\n\n**Priority**\nCritical | High | Medium | Low\n\n**Dependencies**\n- TASK000 (or \"None\")\n\n**Error Handling**\n[Comprehensive error handling - see templates]\n\n**ExUnit Test Requirements**\n- Unit test requirements\n- Test coverage goals\n\n**Integration Test Scenarios**\n- End-to-end test scenarios\n- Performance requirements\n\n**Typespec Requirements**\n- Type specifications needed\n- Documentation requirements\n\n**TypeSpec Documentation**\n- How types will be documented\n\n**TypeSpec Verification**\n- Dialyzer configuration\n- Type checking approach\n\n**Code Quality KPIs**\n- Functions per module: 8\n- Lines per function: 15\n- Call depth: 3\n```","ref":"writing_compliant_tasks.html#task001-task-title"},{"type":"extras","title":"Category-Specific Sections - Writing Compliant Tasks Guide","doc":"Different categories require additional sections:\n\n#### OTP/GenServer Tasks\n```markdown\n**Process Design**\nGenServer vs Task vs Agent decision\n\n**State Management**\nState structure and transitions\n\n**Supervision Strategy**\nRestart strategy and error escalation\n```\n\n#### Phoenix Web Tasks\n```markdown\n**Route Design**\nRESTful routes and path helpers\n\n**Context Integration**\nHow web layer integrates with contexts\n\n**Template/Component Strategy**\nLiveView vs traditional templates\n```\n\n#### Data Layer Tasks\n```markdown\n**Schema Design**\nEcto schema structure\n\n**Migration Strategy**\nSafe migration approach\n\n**Query Optimization**\nPerformance considerations\n```","ref":"writing_compliant_tasks.html#category-specific-sections"},{"type":"extras","title":"Status Rules - Writing Compliant Tasks Guide","doc":"","ref":"writing_compliant_tasks.html#status-rules"},{"type":"extras","title":"In Progress - Writing Compliant Tasks Guide","doc":"- **Must have subtasks** (either numbered or checkbox format)\n- Shows active development","ref":"writing_compliant_tasks.html#in-progress"},{"type":"extras","title":"Completed - Writing Compliant Tasks Guide","doc":"Requires additional sections:\n```markdown\n**Implementation Notes**\nHow it was implemented\n\n**Complexity Assessment**\nLow | Medium | High - explanation\n\n**Maintenance Impact**\nLong-term maintenance considerations\n\n**Error Handling Implementation**\nHow errors were actually handled\n\n**Review Rating**\n4.5 (1-5 scale)\n```","ref":"writing_compliant_tasks.html#completed"},{"type":"extras","title":"Subtask Formats - Writing Compliant Tasks Guide","doc":"","ref":"writing_compliant_tasks.html#subtask-formats"},{"type":"extras","title":"Numbered Format (Major Subtasks) - Writing Compliant Tasks Guide","doc":"Use for subtasks that need detailed tracking:\n\n```markdown\n#### 1. Subtask description (TASK001-1)\n**Description**\nDetailed description of what this subtask does\n\n**Status**\nPlanned\n\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"writing_compliant_tasks.html#numbered-format-major-subtasks"},{"type":"extras","title":"Checkbox Format (Minor Items) - Writing Compliant Tasks Guide","doc":"Use for quick subtasks:\n\n```markdown\n**Subtasks**\n- [x] Completed item [TASK001a]\n- [ ] Pending item [TASK001b]\n- [ ] Another item [TASK001c]\n```","ref":"writing_compliant_tasks.html#checkbox-format-minor-items"},{"type":"extras","title":"Error Handling Requirements - Writing Compliant Tasks Guide","doc":"","ref":"writing_compliant_tasks.html#error-handling-requirements"},{"type":"extras","title":"Main Tasks - Writing Compliant Tasks Guide","doc":"Must use comprehensive format:\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```","ref":"writing_compliant_tasks.html#main-tasks-1"},{"type":"extras","title":"Subtasks - Writing Compliant Tasks Guide","doc":"Use simplified format:\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"writing_compliant_tasks.html#subtasks"},{"type":"extras","title":"Using References - Writing Compliant Tasks Guide","doc":"To reduce file size and maintain consistency, use references:","ref":"writing_compliant_tasks.html#using-references"},{"type":"extras","title":"Define a Reference - Writing Compliant Tasks Guide","doc":"```markdown\n## #{{error-handling}}\n**Error Handling**\n[Full error handling content]\n```","ref":"writing_compliant_tasks.html#define-a-reference"},{"type":"extras","title":"Use a Reference - Writing Compliant Tasks Guide","doc":"```markdown\n{{error-handling}}\n```\n\nCommon references:\n- `{{error-handling}}` - Main task error handling\n- `{{error-handling-subtask}}` - Subtask error handling\n- `{{test-requirements}}` - Integration-first test sections\n- `{{typespec-requirements}}` - TypeSpec sections\n- `{{standard-kpis}}` - Code quality metrics","ref":"writing_compliant_tasks.html#use-a-reference"},{"type":"extras","title":"Common Mistakes to Avoid - Writing Compliant Tasks Guide","doc":"1. **Wrong Error Format** - Don't use main task error handling for subtasks\n2. **Missing Subtasks** - \"In Progress\" tasks must have subtasks\n3. **ID Mismatches** - Subtask prefixes must match parent\n4. **Invalid Status** - Use only: Planned, In Progress, Review, Completed, Blocked\n5. **Missing Sections** - All required sections must be present","ref":"writing_compliant_tasks.html#common-mistakes-to-avoid"},{"type":"extras","title":"Validation Tips - Writing Compliant Tasks Guide","doc":"1. Run validation frequently: `mix validate_tasklist`\n2. Use templates as starting points: `mix task_validator.create_template`\n3. Check examples in `docs/examples/`\n4. Keep references defined at the bottom of the file\n5. Maintain consistent formatting","ref":"writing_compliant_tasks.html#validation-tips"},{"type":"extras","title":"Best Practices - Writing Compliant Tasks Guide","doc":"1. **Start with Templates** - Use category-specific templates\n2. **Use Semantic Prefixes** - OTP, PHX, CTX, DB, INF, TST\n3. **Progressive Detail** - Add sections as tasks progress\n4. **Consistent IDs** - Follow the prefix convention strictly\n5. **Reference Reuse** - Use references for common content","ref":"writing_compliant_tasks.html#best-practices"},{"type":"extras","title":"Examples - Writing Compliant Tasks Guide","doc":"See complete working examples in `docs/examples/`:\n- `otp_genserver_example.md` - OTP/GenServer tasks\n- `phoenix_web_example.md` - Phoenix web tasks\n- `business_logic_example.md` - Context tasks\n- `data_layer_example.md` - Ecto/database tasks\n- `infrastructure_example.md` - DevOps tasks\n- `testing_example.md` - Test implementation tasks","ref":"writing_compliant_tasks.html#examples-1"},{"type":"extras","title":"Sample Task List","doc":"# Sample Task List\n\nThis is a complete sample task list demonstrating all features of TaskValidator.\n\n```markdown\n# Project Task List","ref":"sample_tasklist.html"},{"type":"extras","title":"Current Tasks - Sample Task List","doc":"| ID | Description | Status | Priority | Assignee | Review Rating |\n| --- | --- | --- | --- | --- | --- |\n| OTP0001 | Implement GenServer worker pool | In Progress | High | alice | - |\n| PHX0101 | Create user registration LiveView | Planned | High | - | - |\n| CTX0201 | Design order management context | Planned | Medium | bob | - |","ref":"sample_tasklist.html#current-tasks"},{"type":"extras","title":"Completed Tasks - Sample Task List","doc":"| ID | Description | Status | Priority | Assignee | Review Rating |\n| --- | --- | --- | --- | --- | --- |\n| OTP0002 | Set up supervision tree | Completed | High | alice | 4.5 |\n| DB0301 | Create user schema | Completed | High | charlie | 5.0 |","ref":"sample_tasklist.html#completed-tasks"},{"type":"extras","title":"Active Task Details - Sample Task List","doc":"","ref":"sample_tasklist.html#active-task-details"},{"type":"extras","title":"OTP0001: Implement GenServer worker pool - Sample Task List","doc":"**Description**\nCreate a pool of GenServer workers for handling background jobs with proper load balancing and fault tolerance.\n\n**Simplicity Progression Plan**\n1. Design worker GenServer module\n2. Implement pool supervisor\n3. Add job distribution logic\n4. Create monitoring and metrics\n\n**Simplicity Principle**\nUse OTP patterns with minimal custom abstractions. Leverage existing poolboy library if complexity warrants.\n\n**Abstraction Evaluation**\nMedium - Standard OTP patterns with pool management abstraction.\n\n**Requirements**\n- Pool of 5-10 workers\n- Job queue with priority support\n- Automatic worker restart on failure\n- Metrics and monitoring\n- Backpressure handling\n\n**Process Design**\nGenServer workers managed by a DynamicSupervisor. Each worker maintains its own job queue with overflow to siblings.\n\n**State Management**\nWorker state includes current job, queue, and metrics. Pool supervisor tracks worker availability.\n\n**Supervision Strategy**\nOne-for-one restart strategy with max_restarts: 3, max_seconds: 60. Worker failures don't affect siblings.\n\n{{test-requirements}}\n{{typespec-requirements}}\n{{otp-error-handling}}\n{{otp-kpis}}\n\n**Dependencies**\n- None\n\n**Architecture Notes**\nStandard OTP worker pool pattern with custom job distribution.\n\n**Complexity Assessment**\nMedium - Requires careful state management and job distribution logic.\n\n**Status**: In Progress\n**Priority**: High\n\n#### 1. Design worker GenServer module (OTP0001-1)\n**Description**\nCreate the worker GenServer with job processing callbacks\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n\n{{error-handling-subtask}}\n\n#### 2. Implement pool supervisor (OTP0001-2)\n**Description**\nSet up DynamicSupervisor for managing worker processes\n\n**Status**\nIn Progress\n\n{{error-handling-subtask}}\n\n#### 3. Add job distribution logic (OTP0001-3)\n**Description**\nImplement smart job routing to available workers\n\n**Status**\nPlanned\n\n{{error-handling-subtask}}","ref":"sample_tasklist.html#otp0001-implement-genserver-worker-pool"},{"type":"extras","title":"PHX0101: Create user registration LiveView - Sample Task List","doc":"**Description**\nBuild a real-time user registration form with live validation and smooth UX.\n\n{{phoenix-web-sections}}\n\n**Simplicity Progression Plan**\n1. Create LiveView module structure\n2. Implement form with changesets\n3. Add real-time validations\n4. Integrate with Accounts context\n\n**Simplicity Principle**\nLeverage Phoenix LiveView patterns with minimal custom JavaScript.\n\n**Abstraction Evaluation**\nLow - Direct use of LiveView features.\n\n**Requirements**\n- Email and password fields\n- Real-time validation feedback\n- Password strength indicator\n- Terms acceptance\n- Email confirmation flow\n\n{{test-requirements}}\n{{typespec-requirements}}\n{{phoenix-error-handling}}\n{{phoenix-kpis}}\n{{def-no-dependencies}}\n\n**Status**: Planned\n**Priority**: High","ref":"sample_tasklist.html#phx0101-create-user-registration-liveview"},{"type":"extras","title":"CTX0201: Design order management context - Sample Task List","doc":"**Description**\nCreate a comprehensive order management context with proper business logic separation.\n\n{{business-logic-sections}}\n\n**Simplicity Progression Plan**\n1. Define context API and functions\n2. Implement order CRUD operations\n3. Add business rule validations\n4. Optimize query patterns\n\n**Simplicity Principle**\nClear context boundaries with focused, testable business logic.\n\n**Abstraction Evaluation**\nMedium - Context pattern provides clean separation from web layer.\n\n**Requirements**\n- Order lifecycle management\n- Inventory integration\n- Pricing calculations\n- Order status tracking\n\n{{test-requirements}}\n{{typespec-requirements}}\n{{context-error-handling}}\n{{phoenix-kpis}}\n{{def-no-dependencies}}\n\n**Status**: Planned\n**Priority**: Medium","ref":"sample_tasklist.html#ctx0201-design-order-management-context"},{"type":"extras","title":"Completed Task Details - Sample Task List","doc":"","ref":"sample_tasklist.html#completed-task-details"},{"type":"extras","title":"OTP0002: Set up supervision tree - Sample Task List","doc":"**Description**\nDesign and implement the application supervision tree with proper restart strategies.\n\n**Process Design**\nApplication supervisor with separate subtrees for web, workers, and background jobs.\n\n**State Management**\nMinimal supervisor state, relying on OTP defaults.\n\n**Supervision Strategy**\nRest-for-one strategy at top level, one-for-one for subsystems.\n\n{{test-requirements}}\n{{typespec-requirements}}\n{{otp-error-handling}}\n{{otp-kpis}}\n{{def-no-dependencies}}\n\n**Architecture Notes**\nClean separation of concerns with isolated failure domains.\n\n**Implementation Notes**\nUsed standard OTP supervision patterns with three main subtrees.\n\n**Complexity Assessment**\nLow - Standard OTP patterns throughout.\n\n**Maintenance Impact**\nLow - Well-understood OTP patterns make maintenance straightforward.\n\n**Error Handling Implementation**\nSupervisor handles all crashes with appropriate restart strategies.\n\n**Status**: Completed\n**Priority**: High\n**Review Rating**: 4.5","ref":"sample_tasklist.html#otp0002-set-up-supervision-tree"},{"type":"extras","title":"DB0301: Create user schema - Sample Task List","doc":"**Description**\nDesign and implement the User schema with authentication fields.\n\n{{data-layer-sections}}\n\n**Simplicity Progression Plan**\n1. Define schema fields\n2. Create migration\n3. Add changesets\n4. Implement query helpers\n\n**Simplicity Principle**\nSimple schema with standard Ecto patterns.\n\n**Abstraction Evaluation**\nLow - Direct Ecto usage.\n\n**Requirements**\n- User authentication fields\n- Profile information\n- Timestamps and soft delete\n- Unique constraints\n\n{{test-requirements}}\n{{typespec-requirements}}\n{{ecto-error-handling}}\n{{ecto-kpis}}\n{{def-no-dependencies}}\n\n**Architecture Notes**\nStandard Ecto schema with careful index planning.\n\n**Implementation Notes**\nClean schema with separate changesets for different operations.\n\n**Complexity Assessment**\nLow - Standard Ecto patterns.\n\n**Maintenance Impact**\nLow - Well-structured schema with clear boundaries.\n\n**Error Handling Implementation**\nChangeset-based validation with database constraints as backup.\n\n**Status**: Completed\n**Priority**: High\n**Review Rating**: 5.0","ref":"sample_tasklist.html#db0301-create-user-schema"},{"type":"extras","title":"Reference Definitions - Sample Task List","doc":"## #{{otp-error-handling}}\n**Error Handling**\n**OTP Principles**\n- Let it crash with supervisor restart\n- Use {:ok, result} | {:error, reason} for client functions\n- Handle_call/3 returns for synchronous operations\n**Supervision Strategy**\n- Define restart strategy (permanent/temporary/transient)\n- Set max_restarts and max_seconds appropriately\n- Consider escalation to parent supervisor\n**GenServer Specifics**\n- Handle unexpected messages gracefully\n- Use terminate/2 for cleanup when needed\n- Proper state validation in handle_cast/2\n**Error Examples**\n- Client timeout: {:error, :timeout}\n- Invalid state: {:error, :invalid_state}\n- Resource unavailable: {:error, :unavailable}\n\n## #{{phoenix-error-handling}}\n**Error Handling**\n**Phoenix Principles**\n- Use action_fallback for controller error handling\n- Leverage Plug.ErrorHandler for global error handling\n- Return appropriate HTTP status codes\n**LiveView Error Handling**\n- Handle socket disconnects gracefully\n- Validate assigns before rendering\n- Use handle_info for async error recovery\n**Context Layer**\n- Return structured errors from contexts\n- Use Ecto.Multi for transaction error handling\n- Validate input at context boundaries\n**Error Examples**\n- Validation errors: {:error, %Ecto.Changeset{}}\n- Not found: {:error, :not_found}\n- Unauthorized: {:error, :unauthorized}\n\n## #{{ecto-error-handling}}\n**Error Handling**\n**Ecto Principles**\n- Use changesets for validation errors\n- Handle constraint violations gracefully\n- Use Multi for transactional operations\n**Migration Safety**\n- Always test rollback procedures\n- Handle data integrity during migrations\n- Use constraints instead of validations where possible\n**Error Examples**\n- Validation: {:error, %Ecto.Changeset{}}\n- Constraint: {:error, :constraint_violation}\n- Transaction: {:error, :transaction_failed}\n\n## #{{error-handling-subtask}}\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n\n## #{{test-requirements}}\n**ExUnit Test Requirements**\n- Integration tests FIRST against real dependencies\n- Document actual behavior before mocking\n- Unit tests extracted from integration test observations\n- Test error paths with real error conditions\n- Verify supervisor integration with real processes\n\n**Integration Test Scenarios**\n- Real GenServer processes under supervision\n- Actual message passing and timeouts\n- Real process crashes and restarts\n- Genuine state persistence and recovery\n- Actual distributed node communication\n- Real resource exhaustion scenarios\n\n## #{{typespec-requirements}}\n**Typespec Requirements**:\n- All public functions must have @spec\n- Use custom types for clarity\n- Document complex types\n\n**TypeSpec Documentation**:\n- Clear @doc for all public functions\n- Examples in documentation\n- Parameter constraints documented\n\n**TypeSpec Verification**:\n- Run dialyzer with no warnings\n- Test with invalid inputs\n- Verify type coverage\n\n## #{{otp-kpis}}\n**Code Quality KPIs**\n- Functions per module: 8\n- Lines per function: 15\n- Call depth: 3\n- Pattern match depth: 4\n- Dialyzer warnings: 0\n- Credo score: 8.0\n- GenServer state complexity: 5\n\n## #{{phoenix-kpis}}\n**Code Quality KPIs**\n- Functions per module: 8\n- Lines per function: 15\n- Call depth: 3\n- Pattern match depth: 4\n- Dialyzer warnings: 0\n- Credo score: 8.0\n- Phoenix context boundaries: 3\n\n## #{{ecto-kpis}}\n**Code Quality KPIs**\n- Functions per module: 8\n- Lines per function: 15\n- Call depth: 3\n- Pattern match depth: 4\n- Dialyzer warnings: 0\n- Credo score: 8.0\n- Ecto query complexity: 4\n\n## #{{phoenix-web-sections}}\n**Route Design**\nRESTful routes with proper HTTP verbs and path helpers.\n\n**Context Integration**\nClean integration with Phoenix contexts following domain boundaries.\n\n**Template/Component Strategy**\nLiveView components for real-time features, traditional templates for static content.\n\n## #{{data-layer-sections}}\n**Schema Design**\nWell-normalized schemas with proper field types and constraints.\n\n**Migration Strategy**\nRollback-safe migrations with proper indexes.\n\n**Query Optimization**\nEfficient queries with proper preloading.\n\n## #{{business-logic-sections}}\n**Context Boundaries**\nClear domain boundaries with focused contexts. Minimal cross-context dependencies and clean public APIs.\n\n**Business Rules**\nExplicit business rule validation and enforcement. Clear error handling for business logic violations.\n\n## #{{context-error-handling}}\n**Error Handling**\n**Context Principles**\n- Return structured errors with clear reasons\n- Use Ecto.Multi for complex transactions\n- Validate input at context boundaries\n**Error Examples**\n- Validation: {:error, %Ecto.Changeset{}}\n- Not found: {:error, :not_found}\n- Constraint violation: {:error, :constraint_violation}\n\n## #{{def-no-dependencies}}\n**Dependencies**\n- None\n```","ref":"sample_tasklist.html#reference-definitions"},{"type":"extras","title":"Key Features Demonstrated - Sample Task List","doc":"1. **Multiple Task Categories** - OTP, Phoenix, Context, Database tasks\n2. **Both Task Formats** - Numbered and checkbox subtasks\n3. **Status Progression** - In Progress with subtasks, Completed with all sections\n4. **Reference System** - Extensive use of references to reduce duplication\n5. **Category Sections** - Process Design, Route Design, Schema Design\n6. **Error Handling** - Both main task and subtask formats\n7. **Review Ratings** - Proper format for completed tasks","ref":"sample_tasklist.html#key-features-demonstrated"},{"type":"extras","title":"Common Patterns - Sample Task List","doc":"","ref":"sample_tasklist.html#common-patterns"},{"type":"extras","title":"Starting a New Task - Sample Task List","doc":"1. Add to Current Tasks table\n2. Create detailed section with all required fields\n3. Use appropriate category-specific sections\n4. Start with \"Planned\" status","ref":"sample_tasklist.html#starting-a-new-task"},{"type":"extras","title":"Moving to In Progress - Sample Task List","doc":"1. Change status to \"In Progress\"\n2. Add numbered subtasks for major work\n3. Or add checkbox subtasks for minor items\n4. Update main table","ref":"sample_tasklist.html#moving-to-in-progress"},{"type":"extras","title":"Completing a Task - Sample Task List","doc":"1. Add Implementation Notes\n2. Add Complexity Assessment\n3. Add Maintenance Impact\n4. Add Error Handling Implementation\n5. Add Review Rating\n6. Move to Completed Tasks table","ref":"sample_tasklist.html#completing-a-task"},{"type":"extras","title":"Validation - Sample Task List","doc":"This sample passes all validation rules:\n```bash\nmix validate_tasklist --path guides/sample_tasklist.md\n```\n\nUse this as a template for your own task lists!","ref":"sample_tasklist.html#validation"},{"type":"extras","title":"Configuration Guide","doc":"# Configuration Guide\n\nThis guide explains how to configure and use the TaskValidator in your project.","ref":"configuration.html"},{"type":"extras","title":"Installation - Configuration Guide","doc":"Add `task_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:task_validator, \"~> 0.9.0\"}\n  ]\nend\n```","ref":"configuration.html#installation"},{"type":"extras","title":"Configuration Options - Configuration Guide","doc":"TaskValidator can be configured through your application's config:\n\n```elixir\n# config/config.exs\nconfig :task_validator,\n  default_path: \"docs/TaskList.md\",\n  strict_mode: true,\n  categories: [\n    :otp_genserver,\n    :phoenix_web,\n    :business_logic,\n    :data_layer,\n    :infrastructure,\n    :testing\n  ]\n```","ref":"configuration.html#configuration-options"},{"type":"extras","title":"Configuration Parameters - Configuration Guide","doc":"- **default_path** - Default file path for task lists (default: \"docs/TaskList.md\")\n- **strict_mode** - Enable strict validation rules (default: true)\n- **categories** - List of valid task categories for your project","ref":"configuration.html#configuration-parameters"},{"type":"extras","title":"Environment-Specific Configuration - Configuration Guide","doc":"You can override configuration for different environments:\n\n```elixir\n# config/dev.exs\nconfig :task_validator,\n  strict_mode: false  # More lenient validation in development\n```","ref":"configuration.html#environment-specific-configuration"},{"type":"extras","title":"CLI Configuration - Configuration Guide","doc":"The Mix tasks support command-line options that override configuration:\n\n```bash\n# Override default path\nmix validate_tasklist --path custom/TaskList.md\n\n# Use semantic prefixes\nmix task_validator.create_template --semantic\n\n# Specify category\nmix task_validator.create_template --category otp_genserver\n```","ref":"configuration.html#cli-configuration"},{"type":"extras","title":"Advanced Configuration - Configuration Guide","doc":"","ref":"configuration.html#advanced-configuration"},{"type":"extras","title":"Custom Validators - Configuration Guide","doc":"You can disable specific validators if needed:\n\n```elixir\nconfig :task_validator,\n  disabled_validators: [:kpi_validator]\n```","ref":"configuration.html#custom-validators"},{"type":"extras","title":"Custom Categories - Configuration Guide","doc":"To add custom categories beyond the default Elixir/Phoenix ones:\n\n```elixir\nconfig :task_validator,\n  custom_categories: [\n    {:machine_learning, 700..799, \"ML\"},\n    {:blockchain, 800..899, \"BC\"}\n  ]\n```","ref":"configuration.html#custom-categories"},{"type":"extras","title":"Validation Levels - Configuration Guide","doc":"TaskValidator supports different validation levels:\n\n1. **Strict** - All rules enforced (default)\n2. **Standard** - Common rules enforced, some flexibility\n3. **Lenient** - Basic structure validation only\n\n```elixir\nconfig :task_validator,\n  validation_level: :strict\n```","ref":"configuration.html#validation-levels"},{"type":"extras","title":"Integration with CI/CD - Configuration Guide","doc":"For CI/CD pipelines, you may want stricter validation:\n\n```elixir\n# config/test.exs\nconfig :task_validator,\n  strict_mode: true,\n  fail_on_warnings: true\n```","ref":"configuration.html#integration-with-ci-cd"},{"type":"extras","title":"Troubleshooting - Configuration Guide","doc":"If validation seems incorrect:\n\n1. Check your configuration with `mix task_validator.config`\n2. Ensure you're using the correct environment\n3. Verify file paths are correct\n4. Check for typos in category names","ref":"configuration.html#troubleshooting"},{"type":"extras","title":"See Also - Configuration Guide","doc":"- [Writing Compliant Tasks](writing_compliant_tasks.md)\n- [Example Task Lists](sample_tasklist.md)\n- [README](../README.md) for quick start","ref":"configuration.html#see-also"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}